@@ -9,10 +9,11 @@
 #define SMB4KBOOKMARK_H
 
 // application specific includes
-#include "smb4kglobal.h"
+#include "smb4kglobalenums.h"
 
 // Qt includes
 #include <QIcon>
+#include <QMetaType>
 #include <QScopedPointer>
 #include <QString>
 #include <QUrl>
@@ -60,12 +61,19 @@ public:
      */
     ~Smb4KBookmark();
 
+    /**
+     * Set the share item.
+     *
+     * @param share           The share
+     */
+    void setShare(Smb4KShare *share) const;
+
     /**
      * Set the workgroup name.
      *
      * @param workgroup       The workgroup where the share is located.
      */
-    void setWorkgroupName(const QString &workgroup);
+    void setWorkgroupName(const QString &workgroup) const;
 
     /**
      * Returns the workgroup/domain name.
@@ -74,13 +82,6 @@ public:
      */
     QString workgroupName() const;
 
-    /**
-     * Set the host name.
-     *
-     * @param host            The host where the share is located.
-     */
-    void setHostName(const QString &host);
-
     /**
      * Returns the host name.
      *
@@ -88,13 +89,6 @@ public:
      */
     QString hostName() const;
 
-    /**
-     * Set the share name.
-     *
-     * @param share           The share name
-     */
-    void setShareName(const QString &share);
-
     /**
      * Returns the share name.
      *
@@ -107,7 +101,7 @@ public:
      *
      * @param ip              The host's IP address
      */
-    void setHostIpAddress(const QString &ip);
+    void setHostIpAddress(const QString &ip) const;
 
     /**
      * Returns the host's IP address.
@@ -121,7 +115,7 @@ public:
      *
      * @param type            The type of the share.
      */
-    void setShareType(Smb4KGlobal::ShareType type);
+    void setShareType(Smb4KGlobal::ShareType type) const;
 
     /**
      * Returns the share's type.
@@ -135,7 +129,7 @@ public:
      *
      * @param label         The bookmark's label
      */
-    void setLabel(const QString &label);
+    void setLabel(const QString &label) const;
 
     /**
      * Returns the bookmark's label.
@@ -149,7 +143,7 @@ public:
      *
      * @param name          The user name
      */
-    void setUserName(const QString &name);
+    void setUserName(const QString &name) const;
 
     /**
      * Returns the user name that is used to mount this share.
@@ -163,7 +157,7 @@ public:
      *
      * @param url             The URL of the network item
      */
-    void setUrl(const QUrl &url);
+    void setUrl(const QUrl &url) const;
 
     /**
      * Returns the URL of this bookmark.
@@ -177,7 +171,7 @@ public:
      *
      * @param name            The category name
      */
-    void setCategoryName(const QString &name);
+    void setCategoryName(const QString &name) const;
 
     /**
      * Returns the name of the category this bookmark is in.
@@ -193,7 +187,7 @@ public:
      *
      * @param profile         The profile name
      */
-    void setProfile(const QString &profile);
+    void setProfile(const QString &profile) const;
 
     /**
      * Returns the name of the profile this bookmark belongs to.
@@ -207,7 +201,7 @@ public:
      *
      * @param icon          The icon
      */
-    void setIcon(const QIcon &icon);
+    void setIcon(const QIcon &icon) const;
 
     /**
      * This function returns the icon of the network item. By default, it
@@ -225,8 +219,13 @@ public:
      */
     QString displayString() const;
 
+    /**
+     * Copy assignment operator
+     */
+    Smb4KBookmark &operator=(const Smb4KBookmark &other);
+
 private:
-    const QScopedPointer<Smb4KBookmarkPrivate> d;
+    QScopedPointer<Smb4KBookmarkPrivate> d;
 };
 
 Q_DECLARE_METATYPE(Smb4KBookmark)
