@@ -1,14 +1,13 @@
 /*
     This class handles the bookmarks.
 
-    SPDX-FileCopyrightText: 2004-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2004-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // application specific includes
 #include "smb4kbookmarkhandler.h"
 #include "smb4kbookmark.h"
-#include "smb4kbookmarkhandler_p.h"
 #include "smb4kglobal.h"
 #include "smb4khomesshareshandler.h"
 #include "smb4khost.h"
@@ -23,25 +22,33 @@
 #include <QFile>
 #include <QMutableListIterator>
 #include <QPointer>
-#include <QTextCodec>
 #include <QTextStream>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
 // KDE includes
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 using namespace Smb4KGlobal;
 
+class Smb4KBookmarkHandlerPrivate
+{
+public:
+    QList<BookmarkPtr> bookmarks;
+};
+
+class Smb4KBookmarkHandlerStatic
+{
+public:
+    Smb4KBookmarkHandler instance;
+};
+
 Q_GLOBAL_STATIC(Smb4KBookmarkHandlerStatic, p);
 
 Smb4KBookmarkHandler::Smb4KBookmarkHandler(QObject *parent)
     : QObject(parent)
     , d(new Smb4KBookmarkHandlerPrivate)
 {
-    //
-    // First we need the directory.
-    //
     QString path = dataLocation();
 
     QDir dir;
@@ -50,15 +57,10 @@ Smb4KBookmarkHandler::Smb4KBookmarkHandler(QObject *parent)
         dir.mkpath(path);
     }
 
-    //
-    // Read the list of bookmarks
-    //
     readBookmarkList();
 
-    //
-    // Init the bookmark editor
-    //
-    d->editor = nullptr;
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profileRemoved, this, &Smb4KBookmarkHandler::slotProfileRemoved);
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profileMigrated, this, &Smb4KBookmarkHandler::slotProfileMigrated);
 }
 
 Smb4KBookmarkHandler::~Smb4KBookmarkHandler()
@@ -73,15 +75,6 @@ Smb4KBookmarkHandler *Smb4KBookmarkHandler::self()
     return &p->instance;
 }
 
-void Smb4KBookmarkHandler::addBookmark(const SharePtr &share)
-{
-    if (share) {
-        QList<SharePtr> shares;
-        shares << share;
-        addBookmarks(shares);
-    }
-}
-
 void Smb4KBookmarkHandler::addBookmark(const BookmarkPtr &bookmark)
 {
     if (bookmark) {
@@ -116,69 +109,6 @@ void Smb4KBookmarkHandler::addBookmark(const BookmarkPtr &bookmark)
     }
 }
 
-void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list)
-{
-    //
-    // Prepare the list of bookmarks that should be added
-    //
-    QList<BookmarkPtr> newBookmarks;
-
-    for (const SharePtr &share : list) {
-        //
-        // Printer shares cannot be bookmarked
-        //
-        if (share->isPrinter()) {
-            Smb4KNotification::cannotBookmarkPrinter(share);
-            continue;
-        }
-
-        //
-        // Process homes shares
-        //
-        if (share->isHomesShare() && !Smb4KHomesSharesHandler::self()->specifyUser(share, true)) {
-            continue;
-        }
-
-        //
-        // Check if the share has already been bookmarked and skip it if it
-        // already exists
-        //
-        BookmarkPtr knownBookmark = findBookmarkByUrl(share->isHomesShare() ? share->homeUrl() : share->url());
-
-        if (knownBookmark) {
-            Smb4KNotification::bookmarkExists(knownBookmark);
-            continue;
-        }
-
-        BookmarkPtr bookmark = BookmarkPtr(new Smb4KBookmark(share.data()));
-        bookmark->setProfile(Smb4KProfileManager::self()->activeProfile());
-        newBookmarks << bookmark;
-    }
-
-    //
-    // Show the bookmark dialog, if necessary
-    //
-    if (!newBookmarks.isEmpty()) {
-        QPointer<Smb4KBookmarkDialog> dlg = new Smb4KBookmarkDialog(newBookmarks, categoryList(), QApplication::activeWindow());
-
-        if (dlg->exec() == QDialog::Accepted) {
-            // The bookmark dialog uses an internal list of bookmarks,
-            // so use that one instead of the temporary list created
-            // above.
-            addBookmarks(dlg->bookmarks(), false);
-        }
-
-        delete dlg;
-    }
-
-    //
-    // Clear the temporary list of bookmarks
-    //
-    while (!newBookmarks.isEmpty()) {
-        newBookmarks.takeFirst().clear();
-    }
-}
-
 void Smb4KBookmarkHandler::addBookmarks(const QList<BookmarkPtr> &list, bool replace)
 {
     //
@@ -400,7 +330,7 @@ void Smb4KBookmarkHandler::readBookmarkList()
 BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
 {
     BookmarkPtr bookmark;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarksList();
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
 
     if (!url.isEmpty() && url.isValid() && !temporalBookmarkList.isEmpty()) {
         for (const BookmarkPtr &b : qAsConst(temporalBookmarkList)) {
@@ -423,7 +353,7 @@ BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
 BookmarkPtr Smb4KBookmarkHandler::findBookmarkByLabel(const QString &label)
 {
     BookmarkPtr bookmark;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarksList();
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
 
     for (const BookmarkPtr &b : qAsConst(temporalBookmarkList)) {
         if (QString::compare(b->label().toUpper(), label.toUpper()) == 0) {
@@ -435,7 +365,7 @@ BookmarkPtr Smb4KBookmarkHandler::findBookmarkByLabel(const QString &label)
     return bookmark;
 }
 
-QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList() const
+QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarkList() const
 {
     QList<BookmarkPtr> bookmarks;
 
@@ -454,10 +384,10 @@ QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList() const
     return bookmarks;
 }
 
-QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList(const QString &categoryName) const
+QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarkList(const QString &categoryName) const
 {
     QList<BookmarkPtr> bookmarks;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarksList();
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
 
     for (const BookmarkPtr &bookmark : qAsConst(temporalBookmarkList)) {
         if (categoryName == bookmark->categoryName()) {
@@ -471,7 +401,7 @@ QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList(const QString &categoryNa
 QStringList Smb4KBookmarkHandler::categoryList() const
 {
     QStringList categories;
-    QList<BookmarkPtr> temporalBookmarkList = bookmarksList();
+    QList<BookmarkPtr> temporalBookmarkList = bookmarkList();
 
     for (const BookmarkPtr &bookmark : qAsConst(temporalBookmarkList)) {
         if (!categories.contains(bookmark->categoryName())) {
@@ -482,11 +412,6 @@ QStringList Smb4KBookmarkHandler::categoryList() const
     return categories;
 }
 
-void Smb4KBookmarkHandler::resetBookmarks()
-{
-    readBookmarkList();
-}
-
 bool Smb4KBookmarkHandler::isBookmarked(const SharePtr &share)
 {
     if (findBookmarkByUrl(share->url())) {
@@ -496,30 +421,6 @@ bool Smb4KBookmarkHandler::isBookmarked(const SharePtr &share)
     return false;
 }
 
-void Smb4KBookmarkHandler::editBookmarks()
-{
-    //
-    // Only allow one instance of the bookmark editor
-    //
-    if (!d->editor) {
-        d->editor = new Smb4KBookmarkEditor(bookmarksList(), QApplication::activeWindow());
-    } else {
-        d->editor->raise();
-    }
-
-    if (d->editor->exec() == QDialog::Accepted) {
-        addBookmarks(d->editor->editedBookmarks(), true);
-    } else {
-        resetBookmarks();
-    }
-
-    //
-    // Delete the editor after use
-    //
-    delete d->editor;
-    d->editor = nullptr;
-}
-
 void Smb4KBookmarkHandler::update() const
 {
     for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
@@ -533,27 +434,14 @@ void Smb4KBookmarkHandler::update() const
     }
 }
 
-void Smb4KBookmarkHandler::migrateProfile(const QString &from, const QString &to)
-{
-    // Replace the old profile name with the new one.
-    for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
-        if (QString::compare(bookmark->profile(), from, Qt::CaseSensitive) == 0) {
-            bookmark->setProfile(to);
-        }
-    }
-
-    // Write the new list to the file.
-    writeBookmarkList();
-}
-
-void Smb4KBookmarkHandler::removeProfile(const QString &name)
+void Smb4KBookmarkHandler::slotProfileRemoved(const QString &name)
 {
     QMutableListIterator<BookmarkPtr> it(d->bookmarks);
 
     while (it.hasNext()) {
         const BookmarkPtr &bookmark = it.next();
 
-        if (QString::compare(bookmark->profile(), name, Qt::CaseSensitive) == 0) {
+        if (name == bookmark->profile()) {
             it.remove();
         }
     }
@@ -561,3 +449,16 @@ void Smb4KBookmarkHandler::removeProfile(const QString &name)
     // Write the new list to the file.
     writeBookmarkList();
 }
+
+void Smb4KBookmarkHandler::slotProfileMigrated(const QString &oldName, const QString &newName)
+{
+    for (const BookmarkPtr &bookmark : qAsConst(d->bookmarks)) {
+        if (oldName == bookmark->profile()) {
+            bookmark->setProfile(newName);
+            continue;
+        }
+    }
+
+    // Write the new list to the file.
+    writeBookmarkList();
+}
