@@ -1,7 +1,7 @@
 /*
     This class handles the bookmarks.
 
-    SPDX-FileCopyrightText: 2004-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2004-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -36,7 +36,6 @@ class Q_DECL_EXPORT Smb4KBookmarkHandler : public QObject
     Q_OBJECT
 
     friend class Smb4KBookmarkHandlerPrivate;
-    friend class Smb4KProfileManager;
 
 public:
     /**
@@ -56,13 +55,6 @@ public:
      */
     static Smb4KBookmarkHandler *self();
 
-    /**
-     * This function adds a new bookmark.
-     *
-     * @param share         The share that is to be bookmarked.
-     */
-    void addBookmark(const SharePtr &share);
-
     /**
      * This function adds a new bookmark. The bookmark will be copied
      * internally, so it is save to clear the bookmark pointer after
@@ -72,14 +64,6 @@ public:
      */
     void addBookmark(const BookmarkPtr &bookmark);
 
-    /**
-     * This function adds several bookmarks at once. It takes a list of
-     * shares and converts them internally to bookmark items.
-     *
-     * @param list          The list of shares that are to be bookmarked
-     */
-    void addBookmarks(const QList<SharePtr> &list);
-
     /**
      * This function adds several bookmarks at once. It takes a list of
      * Smb4KBookmark items.
@@ -111,7 +95,7 @@ public:
      * @returns             The current list of bookmarks stored in the
      *                      bookmark file.
      */
-    QList<BookmarkPtr> bookmarksList() const;
+    QList<BookmarkPtr> bookmarkList() const;
 
     /**
      * Get the list of bookmarks belonging to a certain category.
@@ -120,7 +104,7 @@ public:
      *
      * @returns a list of bookmarks belonging to a certain category
      */
-    QList<BookmarkPtr> bookmarksList(const QString &categoryName) const;
+    QList<BookmarkPtr> bookmarkList(const QString &categoryName) const;
 
     /**
      * This function searches for a bookmark using its URL and returns a pointer
@@ -151,11 +135,6 @@ public:
      */
     QStringList categoryList() const;
 
-    /**
-     * Reset the bookmarks by reloading them from the file.
-     */
-    void resetBookmarks();
-
     /**
      * This function checks if the @p share is already bookmarked or not.
      * @param share         The share item
@@ -163,11 +142,6 @@ public:
      */
     bool isBookmarked(const SharePtr &share);
 
-    /**
-     * This function opens the bookmark editor.
-     */
-    void editBookmarks();
-
 Q_SIGNALS:
     /**
      * This signal is emitted when a bookmark was added.
@@ -188,6 +162,22 @@ Q_SIGNALS:
      */
     void updated();
 
+protected Q_SLOTS:
+    /**
+     * Called when a profile was removed
+     *
+     * @param name          The name of the profile
+     */
+    void slotProfileRemoved(const QString &name);
+
+    /**
+     * Called when a profile was migrated
+     *
+     * @param oldName       The old profile name
+     * @param newName       The new profile name
+     */
+    void slotProfileMigrated(const QString &oldName, const QString &newName);
+
 private:
     /**
      * This function reads the list of bookmarks from the bookmarks file.
@@ -204,25 +194,6 @@ private:
      */
     void writeBookmarkList();
 
-    /**
-     * Migrates one profile to another.
-     *
-     * This function is meant to be used by the profile manager.
-     *
-     * @param from        The name of the old profile.
-     * @param to          The name of the new profile.
-     */
-    void migrateProfile(const QString &from, const QString &to);
-
-    /**
-     * Removes a profile from the list of profiles.
-     *
-     * This function is meant to be used by the profile manager.
-     *
-     * @param name        The name of the profile.
-     */
-    void removeProfile(const QString &name);
-
     /**
      * Pointer to Smb4KBookmarkHandlerPrivate class
      */
