@@ -1,7 +1,7 @@
 /*
     This class provides the interface to the libsmbclient library.
 
-    SPDX-FileCopyrightText: 2018-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2018-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -9,9 +9,8 @@
 #include "smb4kclient.h"
 #include "smb4kbasicnetworkitem.h"
 #include "smb4kclient_p.h"
-#include "smb4kcustomoptions.h"
-#include "smb4kcustomoptionsmanager.h"
-#include "smb4kglobal.h"
+#include "smb4kcustomsettings.h"
+#include "smb4kcustomsettingsmanager.h"
 #include "smb4khardwareinterface.h"
 #include "smb4khomesshareshandler.h"
 #include "smb4knotification.h"
@@ -33,10 +32,8 @@ Smb4KClient::Smb4KClient(QObject *parent)
     : KCompositeJob(parent)
     , d(new Smb4KClientPrivate)
 {
-    //
-    // Connections
-    //
-    connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(slotAboutToQuit()));
+    connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, this, &Smb4KClient::slotAboutToQuit);
+    connect(Smb4KWalletManager::self(), &Smb4KWalletManager::credentialsUpdated, this, &Smb4KClient::slotCredentialsUpdated);
 }
 
 Smb4KClient::~Smb4KClient()
@@ -53,7 +50,7 @@ void Smb4KClient::start()
     //
     // Connect to the online state monitoring
     //
-    connect(Smb4KHardwareInterface::self(), SIGNAL(onlineStateChanged(bool)), this, SLOT(slotOnlineStateChanged(bool)), Qt::UniqueConnection);
+    connect(Smb4KHardwareInterface::self(), &Smb4KHardwareInterface::onlineStateChanged, this, &Smb4KClient::slotOnlineStateChanged, Qt::UniqueConnection);
 
     //
     // Start the scanning
@@ -83,7 +80,7 @@ void Smb4KClient::lookupDomains()
     // Send Wakeup-On-LAN packets
     //
     if (Smb4KSettings::enableWakeOnLAN()) {
-        QList<OptionsPtr> wakeOnLanEntries = Smb4KCustomOptionsManager::self()->wakeOnLanEntries();
+        QList<CustomSettingsPtr> wakeOnLanEntries = Smb4KCustomSettingsManager::self()->wakeOnLanEntries();
 
         if (!wakeOnLanEntries.isEmpty()) {
             NetworkItemPtr item = NetworkItemPtr(new Smb4KBasicNetworkItem());
@@ -92,7 +89,7 @@ void Smb4KClient::lookupDomains()
             QUdpSocket *socket = new QUdpSocket(this);
 
             for (int i = 0; i < wakeOnLanEntries.size(); ++i) {
-                if (wakeOnLanEntries.at(i)->wolSendBeforeNetworkScan()) {
+                if (wakeOnLanEntries.at(i)->wakeOnLanSendBeforeNetworkScan()) {
                     QHostAddress addr;
 
                     if (wakeOnLanEntries.at(i)->hasIpAddress()) {
@@ -148,7 +145,7 @@ void Smb4KClient::lookupDomains()
     //
     // Set the busy cursor
     //
-    if (!hasSubjobs() && modifyCursor()) {
+    if (!hasSubjobs()) {
         QApplication::setOverrideCursor(Qt::BusyCursor);
     }
 
@@ -229,7 +226,7 @@ void Smb4KClient::lookupDomainMembers(const WorkgroupPtr &workgroup)
     //
     // Set the busy cursor
     //
-    if (!hasSubjobs() && modifyCursor()) {
+    if (!hasSubjobs()) {
         QApplication::setOverrideCursor(Qt::BusyCursor);
     }
 
@@ -312,7 +309,7 @@ void Smb4KClient::lookupShares(const HostPtr &host)
     //
     // Set the busy cursor
     //
-    if (!hasSubjobs() && modifyCursor()) {
+    if (!hasSubjobs()) {
         QApplication::setOverrideCursor(Qt::BusyCursor);
     }
 
@@ -329,43 +326,32 @@ void Smb4KClient::lookupShares(const HostPtr &host)
 
 void Smb4KClient::lookupFiles(const NetworkItemPtr &item)
 {
-    //
-    // Check that the network item has the correct type and process it.
-    //
-    if (item->type() == Share || item->type() == Directory) {
-        //
-        // Emit the aboutToStart() signal
-        //
+    if (item->type() == Share || (item->type() == FileOrDirectory && item.staticCast<Smb4KFile>()->isDirectory())) {
         Q_EMIT aboutToStart(item, LookupFiles);
 
-        //
-        // Create the job
-        //
         Smb4KClientJob *job = new Smb4KClientJob(this);
         job->setNetworkItem(item);
         job->setProcess(LookupFiles);
 
-        //
-        // Set the busy cursor
-        //
-        if (!hasSubjobs() && modifyCursor()) {
+        if (!hasSubjobs()) {
             QApplication::setOverrideCursor(Qt::BusyCursor);
         }
 
-        //
-        // Add the job to the subjobs
-        //
         addSubjob(job);
 
-        //
-        // Start the job
-        //
         job->start();
     }
 }
 
 void Smb4KClient::printFile(const SharePtr &share, const KFileItem &fileItem, int copies)
 {
+    if (fileItem.mimetype() != QStringLiteral("application/postscript") && fileItem.mimetype() != QStringLiteral("application/pdf")
+        && fileItem.mimetype() != QStringLiteral("application/x-shellscript") && !fileItem.mimetype().startsWith(QStringLiteral("text"))
+        && !fileItem.mimetype().startsWith(QStringLiteral("message")) && !fileItem.mimetype().startsWith(QStringLiteral("image"))) {
+        Smb4KNotification::mimetypeNotSupported(fileItem.mimetype());
+        return;
+    }
+
     //
     // Emit the aboutToStart() signal
     //
@@ -383,7 +369,7 @@ void Smb4KClient::printFile(const SharePtr &share, const KFileItem &fileItem, in
     //
     // Set the busy cursor
     //
-    if (!hasSubjobs() && modifyCursor()) {
+    if (!hasSubjobs()) {
         QApplication::setOverrideCursor(Qt::BusyCursor);
     }
 
@@ -458,147 +444,50 @@ void Smb4KClient::search(const QString &item)
     Q_EMIT finished(networkItem, NetworkSearch);
 }
 
-void Smb4KClient::openPreviewDialog(const SharePtr &share)
-{
-    //
-    // Printer share check
-    //
-    if (share->isPrinter()) {
-        return;
-    }
-
-    //
-    // 'homes' share check
-    //
-    if (share->isHomesShare()) {
-        Smb4KHomesSharesHandler::self()->specifyUser(share, true);
-    }
-
-    //
-    // Start the preview dialog
-    //
-    // First, check if a preview dialog has already been set up for this share
-    // and reuse it, if possible.
-    //
-    QPointer<Smb4KPreviewDialog> dlg = nullptr;
-
-    for (Smb4KPreviewDialog *p : qAsConst(d->previewDialogs)) {
-        if (share == p->share()) {
-            dlg = p;
-        }
-    }
-
-    //
-    // If there was no preview dialog present, create a new one
-    //
-    if (!dlg) {
-        dlg = new Smb4KPreviewDialog(share, QApplication::activeWindow());
-        d->previewDialogs << dlg;
-
-        //
-        // Connections
-        //
-        connect(dlg, SIGNAL(requestPreview(NetworkItemPtr)), this, SLOT(slotStartNetworkQuery(NetworkItemPtr)));
-        connect(dlg, SIGNAL(aboutToClose(Smb4KPreviewDialog *)), this, SLOT(slotPreviewDialogClosed(Smb4KPreviewDialog *)));
-        connect(dlg, SIGNAL(requestAbort()), this, SLOT(slotAbort()));
-        connect(this, SIGNAL(files(QList<FilePtr>)), dlg, SLOT(slotPreviewResults(QList<FilePtr>)));
-        connect(this, SIGNAL(aboutToStart(NetworkItemPtr, int)), dlg, SLOT(slotAboutToStart(NetworkItemPtr, int)));
-        connect(this, SIGNAL(finished(NetworkItemPtr, int)), dlg, SLOT(slotFinished(NetworkItemPtr, int)));
-    }
-
-    //
-    // Show the preview dialog
-    //
-    if (!dlg->isVisible()) {
-        dlg->setVisible(true);
-    }
-}
-
-void Smb4KClient::openPrintDialog(const SharePtr &share)
-{
-    //
-    // Printer share check
-    //
-    if (!share->isPrinter()) {
-        return;
-    }
-
-    //
-    // Start the print dialog
-    //
-    // First, check if a print dialog has already been set up for this share
-    // and reuse it, if possible.
-    //
-    QPointer<Smb4KPrintDialog> dlg = nullptr;
-
-    for (Smb4KPrintDialog *p : qAsConst(d->printDialogs)) {
-        if (share == p->share()) {
-            dlg = p;
-        }
-    }
-
-    //
-    // If there was no print dialog present, create a new one
-    //
-    if (!dlg) {
-        Smb4KWalletManager::self()->readLoginCredentials(share);
-
-        dlg = new Smb4KPrintDialog(share, QApplication::activeWindow());
-        d->printDialogs << dlg;
-
-        connect(dlg, SIGNAL(printFile(SharePtr, KFileItem, int)), this, SLOT(slotStartPrinting(SharePtr, KFileItem, int)));
-        connect(dlg, SIGNAL(aboutToClose(Smb4KPrintDialog *)), this, SLOT(slotPrintDialogClosed(Smb4KPrintDialog *)));
-    }
-
-    //
-    // Show the preview dialog
-    //
-    if (!dlg->isVisible()) {
-        dlg->setVisible(true);
-    }
-}
-
 void Smb4KClient::processErrors(Smb4KClientBaseJob *job)
 {
     switch (job->error()) {
     case Smb4KClientJob::AccessDeniedError: {
         switch (job->networkItem()->type()) {
         case Host: {
-            if (Smb4KWalletManager::self()->showPasswordDialog(job->networkItem())) {
-                lookupShares(job->networkItem().staticCast<Smb4KHost>());
-            }
+            Smb4KClientPrivate::QueueContainer container;
+            container.process = job->process();
+            container.networkItem = job->networkItem();
+            d->queue.append(container);
+            Q_EMIT requestCredentials(job->networkItem());
 
             break;
         }
         case Share: {
-            if (Smb4KWalletManager::self()->showPasswordDialog(job->networkItem())) {
-                if (job->process() == Smb4KGlobal::PrintFile) {
-                    Smb4KClientJob *clientJob = qobject_cast<Smb4KClientJob *>(job);
-                    printFile(job->networkItem().staticCast<Smb4KShare>(), clientJob->printFileItem(), clientJob->printCopies());
-                } else {
-                    lookupFiles(job->networkItem().staticCast<Smb4KShare>());
-                }
+            Smb4KClientPrivate::QueueContainer container;
+            container.process = job->process();
+            container.networkItem = job->networkItem();
+
+            if (job->process() == Smb4KGlobal::PrintFile) {
+                Smb4KClientJob *clientJob = qobject_cast<Smb4KClientJob *>(job);
+                container.printFileItem = clientJob->printFileItem();
+                container.printCopies = clientJob->printCopies();
             }
 
+            d->queue.append(container);
+            Q_EMIT requestCredentials(job->networkItem());
+
             break;
         }
-        case Directory:
-        case File: {
-            FilePtr file = job->networkItem().staticCast<Smb4KFile>();
+        case FileOrDirectory: {
+            Smb4KClientPrivate::QueueContainer container;
+            container.process = job->process();
+            container.networkItem = job->networkItem();
+            d->queue.append(container);
 
+            FilePtr file = job->networkItem().staticCast<Smb4KFile>();
             SharePtr share = SharePtr(new Smb4KShare());
             share->setWorkgroupName(file->workgroupName());
             share->setHostName(file->hostName());
             share->setShareName(file->shareName());
             share->setUserName(file->userName());
             share->setPassword(file->password());
-
-            if (Smb4KWalletManager::self()->showPasswordDialog(share)) {
-                file->setUserName(share->userName());
-                file->setPassword(share->password());
-
-                lookupFiles(file);
-            }
+            Q_EMIT requestCredentials(share);
 
             break;
         }
@@ -868,14 +757,7 @@ void Smb4KClient::processShares(Smb4KClientBaseJob *job)
 
 void Smb4KClient::processFiles(Smb4KClientBaseJob *job)
 {
-    //
-    // Copy the list of discovered files and directories
-    //
     QList<FilePtr> discoveredFiles = job->files();
-
-    //
-    // Process the list of discovered directories
-    //
     QList<FilePtr> list;
 
     for (const FilePtr &file : qAsConst(discoveredFiles)) {
@@ -891,9 +773,6 @@ void Smb4KClient::processFiles(Smb4KClientBaseJob *job)
 
 void Smb4KClient::slotStartJobs()
 {
-    //
-    // Lookup domains as the first step
-    //
     lookupDomains();
 }
 
@@ -929,7 +808,7 @@ void Smb4KClient::slotResult(KJob *job)
     // Get the result from the query and process it
     //
     if (clientBaseJob->error() == 0) {
-        switch (clientBaseJob->networkItem()->type()) {
+        switch (networkItem->type()) {
         case Network: {
             // Process the discovered workgroups
             processWorkgroups(clientBaseJob);
@@ -945,12 +824,16 @@ void Smb4KClient::slotResult(KJob *job)
             processShares(clientBaseJob);
             break;
         }
-        case Share:
-        case Directory: {
-            // Process the discoveres files and directories
+        case Share: {
             processFiles(clientBaseJob);
             break;
         }
+        case FileOrDirectory: {
+            if (networkItem.staticCast<Smb4KFile>()->isDirectory()) {
+                processFiles(clientBaseJob);
+            }
+            break;
+        }
         default: {
             break;
         }
@@ -974,7 +857,7 @@ void Smb4KClient::slotResult(KJob *job)
     //
     // Restore the cursor
     //
-    if (!hasSubjobs() && modifyCursor()) {
+    if (!hasSubjobs()) {
         QApplication::restoreOverrideCursor();
     }
 }
@@ -984,51 +867,63 @@ void Smb4KClient::slotAboutToQuit()
     abort();
 }
 
-void Smb4KClient::slotStartNetworkQuery(NetworkItemPtr item)
-{
-    //
-    // Look up files
-    //
-    lookupFiles(item);
-}
-
-void Smb4KClient::slotPreviewDialogClosed(Smb4KPreviewDialog *dialog)
-{
-    //
-    // Remove the preview dialog from the list
-    //
-    if (dialog) {
-        // Find the dialog in the list and take it from the list.
-        // It will automatically be deleted on close, so there is
-        // no need to delete the dialog here.
-        int i = d->previewDialogs.indexOf(dialog);
-        d->previewDialogs.takeAt(i);
-    }
-}
-
 void Smb4KClient::slotAbort()
 {
     abort();
 }
 
-void Smb4KClient::slotStartPrinting(const SharePtr &printer, const KFileItem &fileItem, int copies)
+void Smb4KClient::slotCredentialsUpdated(const QUrl &url)
 {
-    //
-    // Start printing
-    //
-    printFile(printer, fileItem, copies);
-}
+    if (!url.isEmpty() && !d->queue.isEmpty()) {
+        QMutableListIterator<Smb4KClientPrivate::QueueContainer> it(d->queue);
 
-void Smb4KClient::slotPrintDialogClosed(Smb4KPrintDialog *dialog)
-{
-    //
-    // Remove the print dialog from the list
-    //
-    if (dialog) {
-        // Find the dialog in the list and take it from the list.
-        // It will automatically be deleted on close, so there is
-        // no need to delete the dialog here.
-        int i = d->printDialogs.indexOf(dialog);
-        d->printDialogs.takeAt(i);
+        while (it.hasNext()) {
+            Smb4KClientPrivate::QueueContainer container = it.next();
+
+            QUrl networkItemUrl = container.networkItem->url();
+            QUrl parentNetworkItemUrl = container.networkItem->url().resolved(QUrl(QStringLiteral(".."))).adjusted(QUrl::StripTrailingSlash);
+
+            if (QString::compare(networkItemUrl.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                 url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                 Qt::CaseInsensitive)
+                    == 0
+                || QString::compare(parentNetworkItemUrl.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                    url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                    Qt::CaseInsensitive)
+                    == 0) {
+                switch (container.networkItem->type()) {
+                case Host: {
+                    HostPtr host = container.networkItem.staticCast<Smb4KHost>();
+                    host->setUserName(url.userName());
+                    host->setPassword(url.password());
+                    lookupShares(host);
+                    break;
+                }
+                case Share: {
+                    SharePtr share = container.networkItem.staticCast<Smb4KShare>();
+                    share->setUserName(url.userName());
+                    share->setPassword(url.password());
+                    if (container.process == Smb4KGlobal::PrintFile) {
+                        printFile(share, container.printFileItem, container.printCopies);
+                    } else {
+                        lookupFiles(share);
+                    }
+                    break;
+                }
+                case FileOrDirectory: {
+                    FilePtr file = container.networkItem.staticCast<Smb4KFile>();
+                    file->setUserName(url.userName());
+                    file->setPassword(url.password());
+                    lookupFiles(file);
+                    break;
+                }
+                default: {
+                    break;
+                }
+                }
+
+                it.remove();
+            }
+        }
     }
 }
