@@ -1,7 +1,7 @@
 /*
     Private classes for the SMB client
 
-    SPDX-FileCopyrightText: 2018-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2018-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -20,23 +20,14 @@
 #include <libsmbclient.h>
 
 // Qt includes
-#include <QDialog>
 #include <QHostAddress>
-#include <QListWidgetItem>
 #include <QTimer>
 #include <QUrl>
 
 // KDE includes
-#include <KCoreAddons/KJob>
-#include <kdnssd_version.h>
-#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
 #include <KDNSSD/RemoteService>
 #include <KDNSSD/ServiceBrowser>
-#else
-#include <KDNSSD/DNSSD/RemoteService>
-#include <KDNSSD/DNSSD/ServiceBrowser>
-#endif
-#include <KIOCore/KFileItem>
+#include <KJob>
 
 #ifdef USE_WS_DISCOVERY
 #include <WSDiscoveryClient>
@@ -252,170 +243,18 @@ private:
 };
 #endif
 
-class Smb4KPreviewDialog : public QDialog
-{
-    Q_OBJECT
-
-public:
-    /**
-     * Constructor
-     */
-    Smb4KPreviewDialog(const SharePtr &share, QWidget *parent = nullptr);
-
-    /**
-     * Destructor
-     */
-    ~Smb4KPreviewDialog();
-
-    /**
-     * Returns the share that is previewed
-     *
-     * @returns the share
-     */
-    SharePtr share() const;
-
-Q_SIGNALS:
-    /**
-     * Request a preview
-     */
-    void requestPreview(NetworkItemPtr item);
-
-    /**
-     * Emitted when the dialog is about to close.
-     */
-    void aboutToClose(Smb4KPreviewDialog *dialog);
-
-    /**
-     * Emitted when the process should be aborted
-     */
-    void requestAbort();
-
-protected Q_SLOTS:
-    /**
-     * Do last things before the dialog is closed
-     */
-    void slotClosingDialog();
-
-    /**
-     * Reload
-     */
-    void slotReloadActionTriggered();
-
-    /**
-     * Go up
-     */
-    void slotUpActionTriggered();
-
-    /**
-     * An URL was activated in the combo box
-     *
-     * @param url         The activated URL
-     */
-    void slotUrlActivated(const QUrl &url);
-
-    /**
-     * Process the selected item
-     *
-     * @param item        The activated item
-     */
-    void slotItemActivated(QListWidgetItem *item);
-
-    /**
-     * Initialize the preview
-     */
-    void slotInitializePreview();
-
-    /**
-     * Get the preview results and process them
-     *
-     * @param list        The list of the preview results
-     */
-    void slotPreviewResults(const QList<FilePtr> &list);
-
-    /**
-     * Change the reload/abort dual action
-     */
-    void slotAboutToStart(const NetworkItemPtr &item, int type);
-
-    /**
-     * Change the reload/abort dual action back
-     */
-    void slotFinished(const NetworkItemPtr &item, int type);
-
-private:
-    SharePtr m_share;
-    NetworkItemPtr m_currentItem;
-    QList<FilePtr> m_listing;
-};
-
-class Smb4KPrintDialog : public QDialog
-{
-    Q_OBJECT
-
-public:
-    /**
-     * Constructor
-     */
-    Smb4KPrintDialog(const SharePtr &share, QWidget *parent = nullptr);
-
-    /**
-     * Destructor
-     */
-    ~Smb4KPrintDialog();
-
-    /**
-     * Returns the share that is printed to
-     *
-     * @returns the share
-     */
-    SharePtr share() const;
-
-    /**
-     * Returns the file item that is to be printed
-     *
-     * @returns the file
-     */
-    KFileItem fileItem() const;
-
-Q_SIGNALS:
-    /**
-     * Emitted when a file is to be printed
-     */
-    void printFile(const SharePtr &printer, const KFileItem &file, int copies);
-
-    /**
-     * Emitted when the dialog is about to close
-     */
-    void aboutToClose(Smb4KPrintDialog *dialog);
-
-protected Q_SLOTS:
-    /**
-     * Print button was clicked
-     */
-    void slotPrintButtonClicked();
-
-    /**
-     * Cancel button clicked
-     */
-    void slotCancelButtonClicked();
-
-    /**
-     * Called when the URL was changed
-     */
-    void slotUrlChanged();
-
-private:
-    SharePtr m_share;
-    KFileItem m_fileItem;
-};
-
 class Smb4KClientPrivate
 {
 public:
-    QList<Smb4KPreviewDialog *> previewDialogs;
-    QList<Smb4KPrintDialog *> printDialogs;
+    struct QueueContainer {
+        Smb4KGlobal::Process process;
+        NetworkItemPtr networkItem;
+        KFileItem printFileItem;
+        int printCopies;
+    };
     QList<WorkgroupPtr> tempWorkgroupList;
     QList<HostPtr> tempHostList;
+    QList<QueueContainer> queue;
 };
 
 class Smb4KClientStatic
