@@ -1,7 +1,7 @@
 /*
     This is the global namespace for Smb4K.
 
-    SPDX-FileCopyrightText: 2005-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2005-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -9,6 +9,7 @@
 #include "smb4kglobal.h"
 #include "smb4kclient.h"
 #include "smb4kglobal_p.h"
+#include "smb4kglobalenums.h"
 #include "smb4kmounter.h"
 #include "smb4knotification.h"
 #include "smb4ksynchronizer.h"
@@ -23,51 +24,12 @@
 #include <QUrl>
 
 // KDE includes
-#include <KCoreAddons/KShell>
 #include <KIO/CommandLauncherJob>
 #include <KIO/OpenUrlJob>
-#include <kio_version.h>
 
 Q_GLOBAL_STATIC(Smb4KGlobalPrivate, p);
 QRecursiveMutex mutex;
 
-void Smb4KGlobal::initCore(bool modifyCursor, bool initClasses)
-{
-    if (!p->coreInitialized) {
-        //
-        // Busy cursor
-        //
-        p->modifyCursor = modifyCursor;
-
-        //
-        // Initialize the necessary core classes
-        //
-        if (initClasses) {
-            Smb4KClient::self()->start();
-            Smb4KMounter::self()->start();
-        }
-
-        p->coreInitialized = true;
-    }
-}
-
-void Smb4KGlobal::abortCore()
-{
-    Smb4KClient::self()->abort();
-    Smb4KMounter::self()->abort();
-    Smb4KSynchronizer::self()->abort();
-}
-
-bool Smb4KGlobal::coreIsRunning()
-{
-    return (Smb4KClient::self()->isRunning() || Smb4KMounter::self()->isRunning() || Smb4KSynchronizer::self()->isRunning());
-}
-
-bool Smb4KGlobal::coreIsInitialized()
-{
-    return p->coreInitialized;
-}
-
 const QList<WorkgroupPtr> &Smb4KGlobal::workgroupsList()
 {
     return p->workgroupsList;
@@ -784,11 +746,6 @@ const QString Smb4KGlobal::machineWorkgroupName()
     return p->machineWorkgroupName;
 }
 
-bool Smb4KGlobal::modifyCursor()
-{
-    return p->modifyCursor;
-}
-
 #if defined(Q_OS_LINUX)
 QStringList Smb4KGlobal::allowedMountArguments()
 {
