@@ -1,13 +1,22 @@
 /*
     This is the global namespace for Smb4K.
 
-    SPDX-FileCopyrightText: 2005-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2005-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SMB4KGLOBAL_H
 #define SMB4KGLOBAL_H
 
+// application specific includes
+#include "smb4kbasicnetworkitem.h"
+#include "smb4kbookmark.h"
+#include "smb4kcustomsettings.h"
+#include "smb4kfile.h"
+#include "smb4khost.h"
+#include "smb4kshare.h"
+#include "smb4kworkgroup.h"
+
 // Qt includes
 #include <QEvent>
 #include <QList>
@@ -16,15 +25,6 @@
 #include <QString>
 #include <QStringList>
 
-// forward declarations
-class Smb4KBasicNetworkItem;
-class Smb4KWorkgroup;
-class Smb4KHost;
-class Smb4KShare;
-class Smb4KFile;
-class Smb4KBookmark;
-class Smb4KCustomOptions;
-
 // type definitions
 typedef QSharedPointer<Smb4KBasicNetworkItem> NetworkItemPtr;
 typedef QSharedPointer<Smb4KWorkgroup> WorkgroupPtr;
@@ -32,7 +32,7 @@ typedef QSharedPointer<Smb4KHost> HostPtr;
 typedef QSharedPointer<Smb4KShare> SharePtr;
 typedef QSharedPointer<Smb4KFile> FilePtr;
 typedef QSharedPointer<Smb4KBookmark> BookmarkPtr;
-typedef QSharedPointer<Smb4KCustomOptions> OptionsPtr;
+typedef QSharedPointer<Smb4KCustomSettings> CustomSettingsPtr;
 
 // Other definitions
 #ifndef SMB4K_DEPRECATED
@@ -49,86 +49,6 @@ typedef QSharedPointer<Smb4KCustomOptions> OptionsPtr;
 
 namespace Smb4KGlobal
 {
-/**
- * The Process enumeration.
- *
- * @enum LookupDomains          Look up domains
- * @enum LookupDomainMembers    Look up those servers that belong to a domain/workgroup
- * @enum LookupShares           Look up shares on a server
- * @enum LookupFiles            Look up files and directories within a share
- * @enum WakeUp                 Send magic Wake-On-LAN packets
- * @enum PrintFile              Print a file
- * @enum NetworkSearch          Network search
- * @enum MountShare             Mount a share
- * @enum UnmountShare           Unmount a share
- * @enum NoProcess              No process
- */
-enum Process { LookupDomains, LookupDomainMembers, LookupShares, LookupFiles, WakeUp, PrintFile, NetworkSearch, MountShare, UnmountShare, NoProcess };
-
-/**
- * The enumeration to determine the type of a network item.
- *
- * @enum Network                The network
- * @enum Workgroup              A workgroup
- * @enum Host                   A host
- * @enum Share                  A share
- * @enum Directory              A directory in a shared folder
- * @enum File                   A file in a shared folder
- * @enum UnknownNetworkItem     An unknown network item
- */
-enum NetworkItem { Network, Workgroup, Host, Share, Directory, File, UnknownNetworkItem };
-
-/**
- * The enumeration that determines the share type
- *
- * @enum FileShare              a file share
- * @enum PrinterShare           a printer share
- * @enum IpcShare               an IPC share
- */
-enum ShareType {
-    FileShare,
-    PrinterShare,
-    IpcShare,
-};
-
-/**
- * Use this function to initialize the core classes. Besides starting several
- * core classes such as the scanner (for an initial browse list) and the mounter
- * (for the import of all externally mounted shares), it also sets some default
- * values for some of the settings used to browse the network.
- *
- * By setting the @p modifyCursor parameter to TRUE, you force the core classes
- * to set a busy cursor when they do something. Default is FALSE.
- *
- * Setting @p initClasses to FALSE will avoid starting the core classes. This
- * should only the used if you are starting the core classes in a different
- * way (e. g. if you are starting them in the plasmoid via the Smb4KDeclarative
- * class).
- *
- * You should execute this function before starting your main application.
- */
-Q_DECL_EXPORT void initCore(bool modifyCursor = false, bool initClasses = true);
-
-/**
- * Aborts all actions that are run by the core classes and that can be aborted.
- */
-Q_DECL_EXPORT void abortCore();
-
-/**
- * Check if at least one of the core classes that use KJobs (scanner, mounter, etc.)
- * is running.
- *
- * @returns TRUE if at least one of the core classes is doing something.
- */
-Q_DECL_EXPORT bool coreIsRunning();
-
-/**
- * Check if the core has been initialized through the initCore() function.
- *
- * @returns TRUE if the core has already been initialized.
- */
-Q_DECL_EXPORT bool coreIsInitialized();
-
 /**
  * This function returns the global list of workgroups that were discovered by
  * Smb4K. Use this if you want to access and modify the list with your code.
