@@ -1,22 +1,24 @@
 /*
     Provides an interface to the computer's hardware
 
-    SPDX-FileCopyrightText: 2015-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2015-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // application specific includes
 #include "smb4khardwareinterface.h"
-#include "smb4khardwareinterface_p.h"
 
 // system includes
 #include <unistd.h>
 
 // Qt includes
+#include <QDBusInterface>
 #include <QDBusReply>
+#include <QDBusUnixFileDescriptor>
 #include <QDebug>
 #include <QNetworkInterface>
 #include <QString>
+#include <QStringList>
 #include <QTimer>
 
 // KDE includes
@@ -26,9 +28,27 @@
 #include <Solid/NetworkShare>
 #include <solid_version.h>
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-#include <KIOCore/KMountPoint>
+#include <KMountPoint>
 #endif
 
+class Smb4KHardwareInterfacePrivate
+{
+public:
+#if defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
+    QStringList mountPoints;
+#endif
+    QScopedPointer<QDBusInterface> dbusInterface;
+    QDBusUnixFileDescriptor fileDescriptor;
+    bool systemOnline;
+    QStringList udis;
+};
+
+class Smb4KHardwareInterfaceStatic
+{
+public:
+    Smb4KHardwareInterface instance;
+};
+
 Q_GLOBAL_STATIC(Smb4KHardwareInterfaceStatic, p);
 
 Smb4KHardwareInterface::Smb4KHardwareInterface(QObject *parent)
@@ -67,11 +87,7 @@ Smb4KHardwareInterface::Smb4KHardwareInterface(QObject *parent)
         const Solid::DeviceInterface *iface = device.asDeviceInterface(Solid::DeviceInterface::NetworkShare);
         const Solid::NetworkShare *networkShare = qobject_cast<const Solid::NetworkShare *>(iface);
 
-#if (SOLID_VERSION < QT_VERSION_CHECK(5, 98, 0))
-        if (networkShare && networkShare->type() == Solid::NetworkShare::Cifs) {
-#else
         if (networkShare && (networkShare->type() == Solid::NetworkShare::Cifs || networkShare->type() == Solid::NetworkShare::Smb3)) {
-#endif
             d->udis << device.udi();
         }
     }
@@ -162,19 +178,16 @@ void Smb4KHardwareInterface::checkOnlineState(bool emitSignal)
     }
 }
 
-void Smb4KHardwareInterface::timerEvent(QTimerEvent * /*e*/)
+void Smb4KHardwareInterface::timerEvent(QTimerEvent *event)
 {
-    //
-    // Check for network connectivity
-    //
+    Q_UNUSED(event);
+
     checkOnlineState();
 
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-    //
-    // Using FreeBSD 11 with KF 5.27, Solid is not able to detect mounted shares.
+    // NOTE: Using FreeBSD 11 with KF 5.27, Solid is not able to detect mounted shares.
     // Thus, we check here whether shares have been mounted or unmounted.
     // This is a hack and should be removed as soon as possible.
-    //
     KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::BasicInfoNeeded | KMountPoint::NeedMountOptions);
     QStringList mountPointList, alreadyMounted;
 
@@ -208,7 +221,6 @@ void Smb4KHardwareInterface::timerEvent(QTimerEvent * /*e*/)
     d->mountPoints.clear();
     d->mountPoints.append(alreadyMounted);
     d->mountPoints.append(mountPointList);
-
 #endif
 }
 
@@ -219,11 +231,7 @@ void Smb4KHardwareInterface::slotDeviceAdded(const QString &udi)
     const Solid::DeviceInterface *iface = device.asDeviceInterface(Solid::DeviceInterface::NetworkShare);
     const Solid::NetworkShare *networkShare = qobject_cast<const Solid::NetworkShare *>(iface);
 
-#if (SOLID_VERSION < QT_VERSION_CHECK(5, 98, 0))
-    if (networkShare && networkShare->type() == Solid::NetworkShare::Cifs) {
-#else
     if (networkShare && (networkShare->type() == Solid::NetworkShare::Cifs || networkShare->type() == Solid::NetworkShare::Smb3)) {
-#endif
         d->udis << udi;
         Q_EMIT networkShareAdded();
     }
