@@ -1,7 +1,7 @@
 /*
     Provides an interface to the computer's hardware
 
-    SPDX-FileCopyrightText: 2015-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2015-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -65,10 +65,11 @@ public:
 
 protected:
     /**
-     * Reimplemented from QObject to check for mounts and unmounts on operating
-     * systems that are not fully supported by Solid, yet.
+     * Reimplemented from QObject to check the online state and to check
+     * for mounts and unmounts on operating systems that are not fully
+     * supported by Solid, yet.
      */
-    void timerEvent(QTimerEvent *e) override;
+    void timerEvent(QTimerEvent *event) override;
 
 Q_SIGNALS:
     /**
