@@ -1,7 +1,7 @@
 /*
     Smb4K's container class for information about a host.
 
-    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2008-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -15,7 +15,7 @@
 #include <QUrl>
 
 // KDE includes
-#include <KIconThemes/KIconLoader>
+#include <KIconLoader>
 
 class Smb4KHostPrivate
 {
@@ -34,11 +34,11 @@ Smb4KHost::Smb4KHost(const QUrl &url)
     *pUrl = url;
 }
 
-Smb4KHost::Smb4KHost(const Smb4KHost &h)
-    : Smb4KBasicNetworkItem(h)
+Smb4KHost::Smb4KHost(const Smb4KHost &host)
+    : Smb4KBasicNetworkItem(host)
     , d(new Smb4KHostPrivate)
 {
-    *d = *h.d;
+    *d = *host.d;
 
     if (pIcon->isNull()) {
         *pIcon = KDE::icon(QStringLiteral("network-server"));
@@ -153,3 +153,9 @@ void Smb4KHost::update(Smb4KHost *host)
         }
     }
 }
+
+Smb4KHost &Smb4KHost::operator=(const Smb4KHost &other)
+{
+    *d = *other.d;
+    return *this;
+}
