@@ -1,7 +1,7 @@
 /*
     Smb4K's container class for information about a host.
 
-    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2008-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -181,8 +181,15 @@ public:
      */
     void update(Smb4KHost *host);
 
+    /**
+     * Copy assignment operator
+     */
+    Smb4KHost &operator=(const Smb4KHost &other);
+
 private:
     const QScopedPointer<Smb4KHostPrivate> d;
 };
 
+Q_DECLARE_METATYPE(Smb4KHost)
+
 #endif
