@@ -1,7 +1,7 @@
 /*
     The core class that mounts the shares.
 
-    SPDX-FileCopyrightText: 2003-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2003-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -10,11 +10,10 @@
 #include "smb4kauthinfo.h"
 #include "smb4kbookmark.h"
 #include "smb4kbookmarkhandler.h"
-#include "smb4kcustomoptions.h"
-#include "smb4kcustomoptionsmanager.h"
+#include "smb4kcustomsettings.h"
+#include "smb4kcustomsettingsmanager.h"
 #include "smb4khardwareinterface.h"
 #include "smb4khomesshareshandler.h"
-#include "smb4kmounter_p.h"
 #include "smb4knotification.h"
 #include "smb4kprofilemanager.h"
 #include "smb4ksettings.h"
@@ -33,26 +32,49 @@
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
+#include <QHostInfo>
+#include <QPointer>
+#include <QStorageInfo>
 #include <QTimer>
 #include <QUdpSocket>
 
 // KDE includes
-#include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/ExecuteJob>
-#else
-#include <KAuth/KAuthExecuteJob>
-#endif
-#include <KCoreAddons/KShell>
-#include <KCoreAddons/KUser>
-#include <KI18n/KLocalizedString>
-#include <KIOCore/KMountPoint>
-#include <KWidgetsAddons/KMessageBox>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KMountPoint>
+#include <KShell>
+#include <KUser>
+#include <kauth_version.h>
 
 using namespace Smb4KGlobal;
 
 #define TIMEOUT 50
 
+class Smb4KMounterPrivate
+{
+public:
+    int remountTimeout;
+    int remountAttempts;
+    int timerId;
+    int checkTimeout;
+    int newlyMounted;
+    int newlyUnmounted;
+    QList<SharePtr> importedShares;
+    QList<SharePtr> retries;
+    QList<SharePtr> remounts;
+    bool detectAllShares;
+    bool firstImportDone;
+    bool longActionRunning;
+    QStorageInfo storageInfo;
+};
+
+class Smb4KMounterStatic
+{
+public:
+    Smb4KMounter instance;
+};
+
 Q_GLOBAL_STATIC(Smb4KMounterStatic, p);
 
 Smb4KMounter::Smb4KMounter(QObject *parent)
@@ -67,22 +89,23 @@ Smb4KMounter::Smb4KMounter(QObject *parent)
     d->checkTimeout = 0;
     d->newlyMounted = 0;
     d->newlyUnmounted = 0;
-    d->dialog = nullptr;
     d->firstImportDone = false;
     d->longActionRunning = false;
-    d->activeProfile = Smb4KProfileManager::self()->activeProfile();
     d->detectAllShares = Smb4KMountSettings::detectAllShares();
 
     //
     // Connections
     //
-    connect(Smb4KProfileManager::self(), SIGNAL(migratedProfile(QString, QString)), this, SLOT(slotProfileMigrated(QString, QString)));
-    connect(Smb4KProfileManager::self(), SIGNAL(aboutToChangeProfile()), this, SLOT(slotAboutToChangeProfile()));
-    connect(Smb4KProfileManager::self(), SIGNAL(activeProfileChanged(QString)), this, SLOT(slotActiveProfileChanged(QString)));
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::aboutToChangeProfile, this, &Smb4KMounter::slotAboutToChangeProfile);
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::activeProfileChanged, this, &Smb4KMounter::slotActiveProfileChanged);
+    connect(Smb4KWalletManager::self(), &Smb4KWalletManager::credentialsUpdated, this, &Smb4KMounter::slotCredentialsUpdated);
+    connect(Smb4KMountSettings::self(), &Smb4KMountSettings::configChanged, this, &Smb4KMounter::slotConfigChanged);
 
-    connect(Smb4KMountSettings::self(), SIGNAL(configChanged()), this, SLOT(slotConfigChanged()));
+    connect(Smb4KHardwareInterface::self(), &Smb4KHardwareInterface::onlineStateChanged, this, &Smb4KMounter::slotOnlineStateChanged);
+    connect(Smb4KHardwareInterface::self(), &Smb4KHardwareInterface::networkShareAdded, this, &Smb4KMounter::slotTriggerImport);
+    connect(Smb4KHardwareInterface::self(), &Smb4KHardwareInterface::networkShareRemoved, this, &Smb4KMounter::slotTriggerImport);
 
-    connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(slotAboutToQuit()));
+    connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, this, &Smb4KMounter::slotAboutToQuit);
 }
 
 Smb4KMounter::~Smb4KMounter()
@@ -123,16 +146,16 @@ void Smb4KMounter::triggerRemounts(bool fillList)
         //
         // Get the list of shares that are to be remounted
         //
-        QList<OptionsPtr> options = Smb4KCustomOptionsManager::self()->sharesToRemount();
+        QList<CustomSettingsPtr> options = Smb4KCustomSettingsManager::self()->sharesToRemount();
 
         //
         // Process the list and honor the settings the user chose
         //
-        for (const OptionsPtr &option : qAsConst(options)) {
+        for (const CustomSettingsPtr &option : qAsConst(options)) {
             //
             // Skip one time remount shares, if needed
             //
-            if (option->remount() == Smb4KCustomOptions::RemountOnce && !Smb4KMountSettings::remountShares()) {
+            if (option->remount() == Smb4KCustomSettings::RemountOnce && !Smb4KMountSettings::remountShares()) {
                 continue;
             }
 
@@ -191,36 +214,41 @@ void Smb4KMounter::triggerRemounts(bool fillList)
 
 void Smb4KMounter::import(bool checkInaccessible)
 {
-    //
-    // Immediately return here if we are still processing imported shares
-    //
     if (!d->importedShares.isEmpty()) {
         return;
     }
 
-    //
-    // Boolean to determine at the end if the mounted shares list changed
-    //
-    bool changed = false;
+    bool changedMountedSharesList = false;
+    QStringList allMountPoints;
 
     //
-    // Get the mountpoints that are present on the system
+    // Import new  shares
     //
     KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::BasicInfoNeeded | KMountPoint::NeedMountOptions);
 
-    //
-    // Now determine all mountpoints that have the appropriate filesystem.
-    //
     for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : qAsConst(mountPoints)) {
+        if (!mountPoint->isOnNetwork()) {
+            continue;
+        }
+
         if (mountPoint->mountType() == QStringLiteral("cifs") || mountPoint->mountType() == QStringLiteral("smb3")
             || mountPoint->mountType() == QStringLiteral("smbfs")) {
-            // Create a new share and set the mountpoint and filesystem
+            allMountPoints << mountPoint->mountPoint();
+
+            // Exclude all shares that were already imported. However, while we are
+            // at it, we run a check on them nonetheless.
+            if (SharePtr mountedShare = findShareByPath(mountPoint->mountPoint())) {
+                if (!mountedShare->isInaccessible() || checkInaccessible) {
+                    check(mountedShare);
+                }
+                continue;
+            }
+
             SharePtr share = SharePtr(new Smb4KShare());
             share->setUrl(QUrl(mountPoint->mountedFrom()));
             share->setPath(mountPoint->mountPoint());
             share->setMounted(true);
 
-            // Get all mount options
             QStringList mountOptions = mountPoint->mountOptions();
 
             for (const QString &option : qAsConst(mountOptions)) {
@@ -243,46 +271,17 @@ void Smb4KMounter::import(bool checkInaccessible)
     }
 
     //
-    // Check which shares were unmounted. Remove all obsolete mountpoints, emit
-    // the unmounted() signal on each of the unmounted shares and remove them
-    // from the global list.
+    // Process the shares
     //
-    QList<SharePtr> unmountedShares;
+    SharePtr share;
 
-    if (!d->importedShares.isEmpty()) {
-        bool found = false;
+    QList<SharePtr> mountedShares = mountedSharesList();
+    QMutableListIterator<SharePtr> it(mountedShares);
 
-        for (const SharePtr &mountedShare : qAsConst(mountedSharesList())) {
-            for (const SharePtr &importedShare : qAsConst(d->importedShares)) {
-                // Check the mountpoint, since that one is unique. We will only use
-                // Smb4KShare::path(), so that we do not run into trouble if a share
-                // is inaccessible.
-                if (QString::compare(mountedShare->path(), importedShare->path()) == 0) {
-                    found = true;
-                    break;
-                }
-            }
+    while (it.hasNext()) {
+        share = it.next();
 
-            if (!found) {
-                unmountedShares << mountedShare;
-            }
-
-            found = false;
-        }
-    } else {
-        unmountedShares << mountedSharesList();
-    }
-
-    //
-    // Process the unmounted shares
-    //
-    if (!unmountedShares.isEmpty()) {
-        d->newlyUnmounted += unmountedShares.size();
-
-        for (const SharePtr &share : qAsConst(unmountedShares)) {
-            //
-            // Remove the mountpoint if the share is not a foreign one
-            //
+        if (!allMountPoints.contains(share->path())) {
             if (!share->isForeign()) {
                 QDir dir;
                 dir.cd(share->canonicalPath());
@@ -293,169 +292,104 @@ void Smb4KMounter::import(bool checkInaccessible)
                 }
             }
 
-            //
-            // Mark it as unmounted
-            //
             share->setMounted(false);
 
-            //
-            // Copy the share
-            //
-            SharePtr unmountedShare = share;
-
-            //
-            // Remove the share from the global list and notify the program
-            //
+            // NOTE: We are operating on a copy of the mounted shares list,
+            // so the following should be fine.
             if (removeMountedShare(share)) {
-                changed = true;
-                Q_EMIT unmounted(unmountedShare);
+                d->newlyUnmounted += 1;
+                changedMountedSharesList = true;
+                Q_EMIT unmounted(share);
             }
-
-            //
-            // Report the unmounted share to the user if it is a single one
-            //
-            if (!isRunning() && d->newlyUnmounted == 1) {
-                Smb4KNotification::shareUnmounted(unmountedShare);
-            }
-
-            unmountedShare.clear();
         }
+    }
 
-        //
-        // Report the number of unmounted shares to the user if it are
-        // several ones
-        //
+    if (!isRunning()) {
         if (d->newlyUnmounted > 1) {
             Smb4KNotification::sharesUnmounted(d->newlyUnmounted);
+        } else if (d->newlyUnmounted == 1) {
+            Smb4KNotification::shareUnmounted(share);
         }
 
-        //
-        // Reset the number of newly unmounted shares
-        //
-        d->newlyUnmounted = 0;
-    } else {
-        //
-        // Reset the number of newly unmounted shares
-        //
         d->newlyUnmounted = 0;
     }
 
-    //
-    // Now process the imported shares
-    //
+    share.clear();
+
     if (Smb4KHardwareInterface::self()->isOnline()) {
         while (!d->importedShares.isEmpty()) {
-            SharePtr importedShare = d->importedShares.takeFirst();
-            SharePtr mountedShare = findShareByPath(importedShare->path());
+            share = d->importedShares.takeFirst();
 
-            if (mountedShare) {
-                if (mountedShare->isInaccessible() && !checkInaccessible) {
-                    importedShare.clear();
-                    continue;
-                }
+            check(share);
+
+            if (share->path().startsWith(Smb4KMountSettings::mountPrefix().path())
+                || (!share->isInaccessible() && share->canonicalPath().startsWith(QDir(Smb4KMountSettings::mountPrefix().path()).canonicalPath()))) {
+                share->setForeign(false);
+            } else if (share->path().startsWith(QDir::homePath())
+                       || (!share->isInaccessible() && share->canonicalPath().startsWith(QDir::home().canonicalPath()))) {
+                share->setForeign(false);
+            } else if (share->user().userId() == KUser(KUser::UseRealUserID).userId()
+                       && share->group().groupId() == KUserGroup(KUser::UseRealUserID).groupId()) {
+                share->setForeign(false);
+            } else {
+                share->setForeign(true);
             }
 
-            //
-            // Check the imported share and retrieve some information about it
-            //
-            check(importedShare);
+            if (!share->isForeign() || Smb4KMountSettings::detectAllShares()) {
+                if (addMountedShare(share)) {
+                    d->newlyMounted += 1;
+                    changedMountedSharesList = true;
 
-            //
-            // Find out whether this is a share mounted by the user
-            //
-            if (importedShare->path().startsWith(Smb4KMountSettings::mountPrefix().path())
-                || (!importedShare->isInaccessible()
-                    && importedShare->canonicalPath().startsWith(QDir(Smb4KMountSettings::mountPrefix().path()).canonicalPath()))) {
-                importedShare->setForeign(false);
-            } else if (importedShare->path().startsWith(QDir::homePath())
-                       || (!importedShare->isInaccessible() && importedShare->canonicalPath().startsWith(QDir::home().canonicalPath()))) {
-                importedShare->setForeign(false);
-            } else if (importedShare->user().userId() == KUser(KUser::UseRealUserID).userId()
-                       && importedShare->group().groupId() == KUserGroup(KUser::UseRealUserID).groupId()) {
-                importedShare->setForeign(false);
-            } else {
-                importedShare->setForeign(true);
-            }
+                    // Remove share from the remounts
+                    QMutableListIterator<SharePtr> s(d->remounts);
 
-            //
-            // Search for a previously added mounted share and try to update it. If this fails,
-            // add the share to the global list.
-            //
-            if (!importedShare->isForeign() || Smb4KMountSettings::detectAllShares()) {
-                if (updateMountedShare(importedShare)) {
-                    SharePtr updatedShare = findShareByPath(importedShare->path());
+                    while (s.hasNext()) {
+                        SharePtr remount = s.next();
 
-                    if (updatedShare) {
-                        Q_EMIT updated(updatedShare);
+                        if (!share->isForeign()
+                            && QString::compare(remount->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                                share->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                                Qt::CaseInsensitive)
+                                == 0) {
+                            Smb4KCustomSettingsManager::self()->removeRemount(remount);
+                            s.remove();
+                            break;
+                        }
                     }
 
-                    importedShare.clear();
-                } else {
-                    if (addMountedShare(importedShare)) {
-                        changed = true;
-
-                        // Remove the share from the list of shares that are to be remounted
-                        QMutableListIterator<SharePtr> s(d->remounts);
-
-                        while (s.hasNext()) {
-                            SharePtr remount = s.next();
-
-                            if (!importedShare->isForeign()
-                                && QString::compare(remount->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
-                                                    importedShare->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
-                                                    Qt::CaseInsensitive)
-                                    == 0) {
-                                Smb4KCustomOptionsManager::self()->removeRemount(remount);
-                                s.remove();
-                                break;
-                            } else {
-                                continue;
-                            }
-                        }
-
-                        Q_EMIT mounted(importedShare);
-
-                        // Do not notify the user on first import
-                        if (d->firstImportDone) {
-                            d->newlyMounted += 1;
-
-                            if (!isRunning() && d->importedShares.isEmpty()) {
-                                if (d->newlyMounted > 1) {
-                                    Smb4KNotification::sharesMounted(d->newlyMounted);
-                                } else {
-                                    Smb4KNotification::shareMounted(importedShare);
-                                }
-                                d->newlyMounted = 0;
-                            }
-                        }
-                    } else {
-                        d->newlyMounted = 0;
-                        importedShare.clear();
-                    }
+                    Q_EMIT mounted(share);
                 }
-            } else {
-                importedShare.clear();
             }
         }
 
+        if (!isRunning()) {
+            if (d->firstImportDone) {
+                if (d->newlyMounted > 1) {
+                    Smb4KNotification::sharesMounted(d->newlyMounted);
+                } else if (d->newlyMounted == 1) {
+                    Smb4KNotification::shareMounted(share);
+                }
+            }
+
+            d->newlyMounted = 0;
+        }
+
+        share.clear();
+
         if (!d->firstImportDone && d->importedShares.isEmpty()) {
             d->firstImportDone = true;
         }
     } else {
-        //
-        // When the system is offline, no mounted shares are processed, so
+        // If the system is offline, no mounted shares are processed, so
         // empty the list of imported shares here.
-        //
         while (!d->importedShares.isEmpty()) {
             SharePtr share = d->importedShares.takeFirst();
             share.clear();
         }
     }
 
-    //
-    // Tell the program the list of mounted shares changed
-    //
-    if (changed) {
+    if (changedMountedSharesList) {
+        qDebug() << "Changed list of mounted shares!";
         Q_EMIT mountedSharesListChanged();
     }
 }
@@ -478,10 +412,6 @@ void Smb4KMounter::mountShare(const SharePtr &share)
         QUrl url;
 
         if (share->isHomesShare()) {
-            if (!Smb4KHomesSharesHandler::self()->specifyUser(share, true)) {
-                return;
-            }
-
             url = share->homeUrl();
         } else {
             url = share->url();
@@ -505,9 +435,9 @@ void Smb4KMounter::mountShare(const SharePtr &share)
         // Wake-On-LAN: Wake up the host before mounting
         //
         if (Smb4KSettings::enableWakeOnLAN()) {
-            OptionsPtr options = Smb4KCustomOptionsManager::self()->findOptions(share->url().resolved(QUrl(QStringLiteral(".."))));
+            CustomSettingsPtr customSettings = Smb4KCustomSettingsManager::self()->findCustomSettings(share->url().resolved(QUrl(QStringLiteral(".."))));
 
-            if (options && options->wolSendBeforeMount()) {
+            if (customSettings && customSettings->wakeOnLanSendBeforeMount()) {
                 Q_EMIT aboutToStart(WakeUp);
 
                 QUdpSocket *socket = new QUdpSocket(this);
@@ -529,7 +459,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
                 }
 
                 // 16 times the MAC address
-                QStringList parts = options->macAddress().split(QStringLiteral(":"), Qt::SkipEmptyParts);
+                QStringList parts = customSettings->macAddress().split(QStringLiteral(":"), Qt::SkipEmptyParts);
 
                 for (int j = 0; j < 16; ++j) {
                     for (int k = 0; k < parts.size(); ++k) {
@@ -635,7 +565,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
         //
         // Modify the cursor, if necessary.
         //
-        if (!hasSubjobs() && modifyCursor()) {
+        if (!hasSubjobs()) {
             QApplication::setOverrideCursor(Qt::BusyCursor);
         }
 
@@ -660,9 +590,8 @@ void Smb4KMounter::mountShare(const SharePtr &share)
 #if defined(Q_OS_LINUX)
                     if (errorMsg.contains(QStringLiteral("mount error 13"))
                         || errorMsg.contains(QStringLiteral("mount error(13)")) /* authentication error */) {
-                        if (Smb4KWalletManager::self()->showPasswordDialog(share)) {
-                            d->retries << share;
-                        }
+                        d->retries << share;
+                        Q_EMIT requestCredentials(share);
                     } else if (errorMsg.contains(QStringLiteral("Unable to find suitable address."))) {
                         // Swallow this
                     } else {
@@ -670,9 +599,8 @@ void Smb4KMounter::mountShare(const SharePtr &share)
                     }
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
                     if (errorMsg.contains(QStringLiteral("Authentication error")) || errorMsg.contains(QStringLiteral("Permission denied"))) {
-                        if (Smb4KWalletManager::self()->showPasswordDialog(share)) {
-                            d->retries << share;
-                        }
+                        d->retries << share;
+                        Q_EMIT requestCredentials(share);
                     } else {
                         Smb4KNotification::mountingFailed(share, errorMsg);
                     }
@@ -696,7 +624,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
         //
         // Reset the busy cursor
         //
-        if (!hasSubjobs() && modifyCursor()) {
+        if (!hasSubjobs()) {
             QApplication::restoreOverrideCursor();
         }
 
@@ -752,14 +680,16 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
                 return;
             } else {
                 if (!silent) {
-                    if (KMessageBox::warningYesNo(QApplication::activeWindow(),
-                                                  i18n("<p>The share <b>%1</b> is mounted to <br><b>%2</b> and owned by user <b>%3</b>.</p>"
-                                                       "<p>Do you really want to unmount it?</p>",
-                                                       share->displayString(),
-                                                       share->path(),
-                                                       share->user().loginName()),
-                                                  i18n("Foreign Share"))
-                        == KMessageBox::No) {
+                    if (KMessageBox::warningTwoActions(QApplication::activeWindow(),
+                                                       i18n("<p>The share <b>%1</b> is mounted to <br><b>%2</b> and owned by user <b>%3</b>.</p>"
+                                                            "<p>Do you really want to unmount it?</p>",
+                                                            share->displayString(),
+                                                            share->path(),
+                                                            share->user().loginName()),
+                                                       i18n("Foreign Share"),
+                                                       KStandardGuiItem::ok(),
+                                                       KStandardGuiItem::cancel())
+                        == KMessageBox::SecondaryAction) {
                         return;
                     }
                 } else {
@@ -812,7 +742,7 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
         //
         // Modify the cursor, if necessary.
         //
-        if (!hasSubjobs() && modifyCursor()) {
+        if (!hasSubjobs()) {
             QApplication::setOverrideCursor(Qt::BusyCursor);
         }
 
@@ -852,7 +782,7 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
         //
         // Reset the busy cursor
         //
-        if (!hasSubjobs() && modifyCursor()) {
+        if (!hasSubjobs()) {
             QApplication::restoreOverrideCursor();
         }
 
@@ -899,44 +829,8 @@ void Smb4KMounter::unmountAllShares(bool silent)
     unmountShares(mountedSharesList(), silent);
 }
 
-void Smb4KMounter::openMountDialog()
-{
-    if (!d->dialog) {
-        SharePtr share = SharePtr(new Smb4KShare());
-        BookmarkPtr bookmark = BookmarkPtr(new Smb4KBookmark());
-
-        d->dialog = new Smb4KMountDialog(share, bookmark, QApplication::activeWindow());
-
-        if (d->dialog->exec() == QDialog::Accepted && d->dialog->validUserInput()) {
-            // Pass the share to mountShare().
-            mountShare(share);
-
-            // Bookmark the share if the user wants this.
-            if (d->dialog->bookmarkShare()) {
-                Smb4KBookmarkHandler::self()->addBookmark(bookmark);
-            }
-        }
-
-        delete d->dialog;
-        d->dialog = nullptr;
-
-        share.clear();
-        bookmark.clear();
-    }
-}
-
 void Smb4KMounter::start()
 {
-    //
-    // Connect to the relevant signals provided by Smb4KHardwareInterface.
-    //
-    connect(Smb4KHardwareInterface::self(), SIGNAL(onlineStateChanged(bool)), this, SLOT(slotOnlineStateChanged(bool)), Qt::UniqueConnection);
-    connect(Smb4KHardwareInterface::self(), SIGNAL(networkShareAdded()), this, SLOT(slotTriggerImport()), Qt::UniqueConnection);
-    connect(Smb4KHardwareInterface::self(), SIGNAL(networkShareRemoved()), this, SLOT(slotTriggerImport()), Qt::UniqueConnection);
-
-    //
-    // Start with importing shares
-    //
     if (Smb4KHardwareInterface::self()->isOnline()) {
         QTimer::singleShot(50, this, SLOT(slotStartJobs()));
     }
@@ -949,9 +843,9 @@ void Smb4KMounter::saveSharesForRemount()
     //
     for (const SharePtr &share : mountedSharesList()) {
         if (!share->isForeign()) {
-            Smb4KCustomOptionsManager::self()->addRemount(share, false);
+            Smb4KCustomSettingsManager::self()->addRemount(share, false);
         } else {
-            Smb4KCustomOptionsManager::self()->removeRemount(share, false);
+            Smb4KCustomSettingsManager::self()->removeRemount(share, false);
         }
     }
 
@@ -960,7 +854,7 @@ void Smb4KMounter::saveSharesForRemount()
     //
     while (!d->remounts.isEmpty()) {
         SharePtr share = d->remounts.takeFirst();
-        Smb4KCustomOptionsManager::self()->addRemount(share, false);
+        Smb4KCustomSettingsManager::self()->addRemount(share, false);
         share.clear();
     }
 }
@@ -984,15 +878,6 @@ void Smb4KMounter::timerEvent(QTimerEvent *)
             d->remountTimeout += TIMEOUT;
         }
 
-        //
-        // Retry to mount those shares that initially failed
-        //
-        while (!d->retries.isEmpty()) {
-            SharePtr share = d->retries.takeFirst();
-            mountShare(share);
-            share.clear();
-        }
-
         //
         // Check the size, accessibility, etc. of the shares
         //
@@ -1030,7 +915,7 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap &map)
     //
     // Global and custom options
     //
-    OptionsPtr options = Smb4KCustomOptionsManager::self()->findOptions(share);
+    CustomSettingsPtr options = Smb4KCustomSettingsManager::self()->findCustomSettings(share);
 
     //
     // Pass the remote file system port to the URL
@@ -1498,7 +1383,7 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap &map)
     //
     // Global and custom options
     //
-    OptionsPtr options = Smb4KCustomOptionsManager::self()->findOptions(share);
+    CustomSettingsPtr options = Smb4KCustomSettingsManager::self()->findCustomSettings(share);
 
     //
     // List of arguments
@@ -1891,9 +1776,6 @@ void Smb4KMounter::slotOnlineStateChanged(bool online)
 
 void Smb4KMounter::slotAboutToChangeProfile()
 {
-    //
-    // Save those shares that are to be remounted
-    //
     if (Smb4KMountSettings::remountShares()) {
         saveSharesForRemount();
     }
@@ -1901,53 +1783,39 @@ void Smb4KMounter::slotAboutToChangeProfile()
 
 void Smb4KMounter::slotActiveProfileChanged(const QString &newProfile)
 {
-    if (d->activeProfile != newProfile) {
-        // Stop the timer.
-        killTimer(d->timerId);
+    Q_UNUSED(newProfile);
 
-        abort();
+    // Stop the timer.
+    killTimer(d->timerId);
 
-        // Clear all remounts.
-        while (!d->remounts.isEmpty()) {
-            d->remounts.takeFirst().clear();
-        }
+    abort();
 
-        // Clear all retries.
-        while (!d->retries.isEmpty()) {
-            d->retries.takeFirst().clear();
-        }
-
-        // Unmount all shares
-        unmountAllShares(true);
-
-        // Reset some variables.
-        // Don't touch d->firstImportDone here, because that remains true
-        d->remountTimeout = 0;
-        d->remountAttempts = 0;
-        d->activeProfile = newProfile;
-
-        // Restart the timer
-        d->timerId = startTimer(TIMEOUT);
+    // Clear all remounts.
+    while (!d->remounts.isEmpty()) {
+        d->remounts.takeFirst().clear();
     }
-}
 
-void Smb4KMounter::slotProfileMigrated(const QString &from, const QString &to)
-{
-    if (QString::compare(from, d->activeProfile, Qt::CaseSensitive) == 0) {
-        d->activeProfile = to;
+    // Clear all retries.
+    while (!d->retries.isEmpty()) {
+        d->retries.takeFirst().clear();
     }
+
+    // Unmount all shares
+    unmountAllShares(true);
+
+    // Reset some variables.
+    // Don't touch d->firstImportDone here, because that remains true
+    d->remountTimeout = 0;
+    d->remountAttempts = 0;
+
+    // Restart the timer
+    d->timerId = startTimer(TIMEOUT);
 }
 
 void Smb4KMounter::slotTriggerImport()
 {
-    //
-    // Wait a bit so that the mount or unmount process can finish and
-    // then start importing the shares, if no jobs are running anymore
-    //
     QTimer::singleShot(2 * TIMEOUT, this, [&]() {
-        if (!isRunning()) {
-            import(true);
-        }
+        import(true);
     });
 }
 
@@ -1958,3 +1826,32 @@ void Smb4KMounter::slotConfigChanged()
         d->detectAllShares = Smb4KMountSettings::detectAllShares();
     }
 }
+
+void Smb4KMounter::slotCredentialsUpdated(const QUrl &url)
+{
+    if (!url.isEmpty() && !d->retries.isEmpty()) {
+        QMutableListIterator<SharePtr> it(d->retries);
+
+        while (it.hasNext()) {
+            SharePtr share = it.next();
+
+            QUrl parentUrl = share->url().resolved(QUrl(QStringLiteral(".."))).adjusted(QUrl::StripTrailingSlash);
+
+            if (QString::compare(share->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                 url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                 Qt::CaseInsensitive)
+                    == 0
+                || QString::compare(parentUrl.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                    url.toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
+                                    Qt::CaseInsensitive)
+                    == 0) {
+                share->setUserName(url.userName());
+                share->setPassword(url.password());
+
+                mountShare(share);
+
+                it.remove();
+            }
+        }
+    }
+}
