@@ -1,7 +1,7 @@
 /*
     The core class that mounts the shares.
 
-    SPDX-FileCopyrightText: 2003-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2003-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -21,12 +21,11 @@
 #include <QVariant>
 
 // KDE includes
-#include <KCoreAddons/KCompositeJob>
+#include <KCompositeJob>
 
 // forward declarations
 class Smb4KShare;
 class Smb4KAuthInfo;
-class Smb4KMountDialog;
 class Smb4KMountJob;
 class Smb4KUnmountJob;
 class Smb4KMounterPrivate;
@@ -112,12 +111,6 @@ public:
      */
     void unmountAllShares(bool silent);
 
-    /**
-     * Mount a share via a mount dialog. The mount dialog is opened and you have
-     * to enter the UNC and optionally the workgroup and IP address.
-     */
-    void openMountDialog();
-
     /**
      * This function reports if the mounter is running or not.
      *
@@ -176,6 +169,14 @@ Q_SIGNALS:
      */
     void mountedSharesListChanged();
 
+    /**
+     * Emitted when credentials are requested from elsewhere
+     *
+     * @param share             The share for which the credentials
+     *                          are requested
+     */
+    void requestCredentials(const SharePtr &share);
+
 protected:
     /**
      * Reimplemented from QObject to process the queue.
@@ -214,14 +215,6 @@ protected Q_SLOTS:
      */
     void slotActiveProfileChanged(const QString &newProfile);
 
-    /**
-     * This slot is called when a profile was migrated.
-     *
-     * @param from            The old profile
-     * @param to              The new profile
-     */
-    void slotProfileMigrated(const QString &from, const QString &to);
-
     /**
      * This slot is called whenever a network share is mounted or
      * unmounted.
@@ -234,6 +227,11 @@ protected Q_SLOTS:
      */
     void slotConfigChanged();
 
+    /**
+     * Called when the credentials were updated
+     */
+    void slotCredentialsUpdated(const QUrl &url);
+
 private:
     /**
      * Trigger the remounting of shares. If the parameter @p fill_list is
