@@ -1,7 +1,7 @@
 /*
     This class provides notifications for Smb4K.
 
-    SPDX-FileCopyrightText: 2010-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2010-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -18,18 +18,27 @@
 
 // KDE includes
 #include "kauth_version.h"
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/ActionReply>
-#else
-#include <KAuth/KAuthActionReply>
-#endif
-#include <KI18n/KLocalizedString>
 #include <KIO/OpenUrlJob>
-#include <KIconThemes/KIconLoader>
-#include <KNotifications/KNotification>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KNotification>
 
 using namespace KAuth;
 
+class Smb4KNotificationPrivate
+{
+public:
+    QString componentName;
+};
+
+Q_GLOBAL_STATIC(Smb4KNotificationPrivate, p);
+
+void Smb4KNotification::setComponentName(const QString &name)
+{
+    p->componentName = name;
+}
+
 //
 // Notifications
 //
@@ -42,21 +51,32 @@ void Smb4KNotification::shareMounted(const SharePtr &share)
         QEventLoop loop;
 
         KNotification *notification = new KNotification(QStringLiteral("shareMounted"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(i18n("<p>The share <b>%1</b> has been mounted to <b>%2</b>.</p>", share->displayString(), share->path()));
         notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("folder-network"),
                                                                 KIconLoader::NoGroup,
                                                                 0,
                                                                 KIconLoader::DefaultState,
                                                                 QStringList(QStringLiteral("emblem-mounted"))));
-        notification->setActions(QStringList(i18nc("Open the contents of the share with the file manager", "Open")));
 
-        QObject::connect(notification, &KNotification::action1Activated, [&]() {
+        auto open = [&]() {
             KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(share->path()), QStringLiteral("inode/directory"));
             job->setFollowRedirections(false);
             job->setAutoDelete(true);
             job->start();
-        });
+        };
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        auto *openAction = notification->addAction(i18nc("Open the contents of the share with the file manager", "Open"));
+        QObject::connect(openAction, &KNotificationAction::activated, open);
+#else
+        notification->setActions(QStringList(i18nc("Open the contents of the share with the file manager", "Open")));
+        QObject::connect(notification, &KNotification::action1Activated, open);
+#endif
         QObject::connect(notification, &KNotification::closed, &loop, &QEventLoop::quit);
 
         notification->sendEvent();
@@ -71,6 +91,11 @@ void Smb4KNotification::shareUnmounted(const SharePtr &share)
 
     if (share) {
         KNotification *notification = new KNotification(QStringLiteral("shareUnmounted"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(i18n("<p>The share <b>%1</b> has been unmounted from <b>%2</b>.</p>", share->displayString(), share->path()));
         notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("folder-network"),
                                                                 KIconLoader::NoGroup,
@@ -84,6 +109,11 @@ void Smb4KNotification::shareUnmounted(const SharePtr &share)
 void Smb4KNotification::sharesMounted(int number)
 {
     KNotification *notification = new KNotification(QStringLiteral("sharesMounted"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18np("<p>%1 share has been mounted.</p>", "<p>%1 shares have been mounted.</p>", number));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("folder-network"),
                                                             KIconLoader::NoGroup,
@@ -96,6 +126,11 @@ void Smb4KNotification::sharesMounted(int number)
 void Smb4KNotification::sharesUnmounted(int number)
 {
     KNotification *notification = new KNotification(QStringLiteral("sharesUnmounted"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18np("<p>%1 share has been unmounted.</p>", "<p>%1 shares have been unmounted.</p>", number));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("folder-network"),
                                                             KIconLoader::NoGroup,
@@ -112,6 +147,11 @@ void Smb4KNotification::sharesUnmounted(int number)
 void Smb4KNotification::openingWalletFailed(const QString &name)
 {
     KNotification *notification = new KNotification(QStringLiteral("openingWalletFailed"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18n("<p>Opening the wallet <b>%1</b> failed.</p>", name));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-warning"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -120,6 +160,11 @@ void Smb4KNotification::openingWalletFailed(const QString &name)
 void Smb4KNotification::credentialsNotAccessible()
 {
     KNotification *notification = new KNotification(QStringLiteral("credentialsNotAccessible"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(
         i18n("<p>The credentials stored in the wallet could not be accessed. "
              "There is either no wallet available or it could not be opened.</p>"));
@@ -130,6 +175,11 @@ void Smb4KNotification::credentialsNotAccessible()
 void Smb4KNotification::mimetypeNotSupported(const QString &mimetype)
 {
     KNotification *notification = new KNotification(QStringLiteral("mimetypeNotSupported"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(
         i18n("<p>The mimetype <b>%1</b> is not supported for printing. "
              "Please convert the file to PDF or Postscript and try again.</p>",
@@ -144,6 +194,11 @@ void Smb4KNotification::bookmarkExists(const BookmarkPtr &bookmark)
 
     if (bookmark) {
         KNotification *notification = new KNotification(QStringLiteral("bookmarkExists"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(i18n("<p>The bookmark for share <b>%1</b> already exists and will be skipped.</p>", bookmark->displayString()));
         notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-warning"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
         notification->sendEvent();
@@ -156,6 +211,11 @@ void Smb4KNotification::bookmarkLabelInUse(const BookmarkPtr &bookmark)
 
     if (bookmark) {
         KNotification *notification = new KNotification(QStringLiteral("bookmarkLabelInUse"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(
             i18n("<p>The label <b>%1</b> of the bookmark for the share <b>%2</b> "
                  "is already being used and will automatically be renamed.</p>",
@@ -183,6 +243,11 @@ void Smb4KNotification::mountingFailed(const SharePtr &share, const QString &err
         }
 
         KNotification *notification = new KNotification(QStringLiteral("mountingFailed"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(text);
         notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
         notification->sendEvent();
@@ -203,6 +268,11 @@ void Smb4KNotification::unmountingFailed(const SharePtr &share, const QString &e
         }
 
         KNotification *notification = new KNotification(QStringLiteral("unmountingFailed"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(text);
         notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
         notification->sendEvent();
@@ -215,6 +285,11 @@ void Smb4KNotification::unmountingNotAllowed(const SharePtr &share)
 
     if (share) {
         KNotification *notification = new KNotification(QStringLiteral("unmountingNotAllowed"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(
             i18n("<p>You are not allowed to unmount the share <b>%1</b> from <b>%2</b>. "
                  "It is owned by the user <b>%3</b>.</p>",
@@ -237,6 +312,11 @@ void Smb4KNotification::synchronizationFailed(const QUrl &src, const QUrl &dest,
     }
 
     KNotification *notification = new KNotification(QStringLiteral("synchronizationFailed"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(text);
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -245,6 +325,11 @@ void Smb4KNotification::synchronizationFailed(const QUrl &src, const QUrl &dest,
 void Smb4KNotification::commandNotFound(const QString &command)
 {
     KNotification *notification = new KNotification(QStringLiteral("commandNotFound"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18n("<p>The command <b>%1</b> could not be found. Please check your installation.</p>", command));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -256,6 +341,11 @@ void Smb4KNotification::cannotBookmarkPrinter(const SharePtr &share)
 
     if (share && share->isPrinter()) {
         KNotification *notification = new KNotification(QStringLiteral("cannotBookmarkPrinter"), KNotification::CloseOnTimeout);
+
+        if (!p->componentName.isEmpty()) {
+            notification->setComponentName(p->componentName);
+        }
+
         notification->setText(i18n("<p>The share <b>%1</b> is a printer and cannot be bookmarked.</p>", share->displayString()));
         notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
         notification->sendEvent();
@@ -265,6 +355,11 @@ void Smb4KNotification::cannotBookmarkPrinter(const SharePtr &share)
 void Smb4KNotification::fileNotFound(const QString &fileName)
 {
     KNotification *notification = new KNotification(QStringLiteral("fileNotFound"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18n("<p>The file <b>%1</b> could not be found.</p>", fileName));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -281,6 +376,11 @@ void Smb4KNotification::openingFileFailed(const QFile &file)
     }
 
     KNotification *notification = new KNotification(QStringLiteral("openingFileFailed"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(text);
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -301,6 +401,11 @@ void Smb4KNotification::readingFileFailed(const QFile &file, const QString &err_
     }
 
     KNotification *notification = new KNotification(QStringLiteral("readingFileFailed"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(text);
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -309,6 +414,11 @@ void Smb4KNotification::readingFileFailed(const QFile &file, const QString &err_
 void Smb4KNotification::mkdirFailed(const QDir &dir)
 {
     KNotification *notification = new KNotification(QStringLiteral("mkdirFailed"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18n("<p>The following directory could not be created:</p><p><tt>%1</tt></p>", dir.absolutePath()));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -347,6 +457,11 @@ void Smb4KNotification::processError(QProcess::ProcessError error)
     }
 
     KNotification *notification = new KNotification(QStringLiteral("processError"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(text);
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -405,6 +520,11 @@ void Smb4KNotification::actionFailed(int errorCode)
     }
 
     KNotification *notification = new KNotification(QStringLiteral("actionFailed"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(text);
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -413,6 +533,11 @@ void Smb4KNotification::actionFailed(int errorCode)
 void Smb4KNotification::invalidURLPassed()
 {
     KNotification *notification = new KNotification(QStringLiteral("invalidURL"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18n("<p>The URL that was passed is invalid.</p>"));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -421,6 +546,11 @@ void Smb4KNotification::invalidURLPassed()
 void Smb4KNotification::networkCommunicationFailed(const QString &errorMessage)
 {
     KNotification *notification = new KNotification(QStringLiteral("networkCommunicationFailed"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18n("<p>The network communication failed with the following error message: <s>%1</s></p>", errorMessage));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
@@ -429,6 +559,11 @@ void Smb4KNotification::networkCommunicationFailed(const QString &errorMessage)
 void Smb4KNotification::zeroconfError(const QString &errorMessage)
 {
     KNotification *notification = new KNotification(QStringLiteral("zeroconfError"), KNotification::CloseOnTimeout);
+
+    if (!p->componentName.isEmpty()) {
+        notification->setComponentName(p->componentName);
+    }
+
     notification->setText(i18n("<p>An error with the Zeroconf service occurred: <s>%1</s></p>", errorMessage));
     notification->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-error"), KIconLoader::NoGroup, 0, KIconLoader::DefaultState));
     notification->sendEvent();
