@@ -1,13 +1,16 @@
 /*
     This class manages the profiles that were defined by the user.
 
-    SPDX-FileCopyrightText: 2014-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2014-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SMB4KPROFILEMANAGER_H
 #define SMB4KPROFILEMANAGER_H
 
+// application specific includes
+#include "smb4kglobal.h"
+
 // Qt includes
 #include <QObject>
 #include <QPair>
@@ -89,52 +92,42 @@ public:
     bool useProfiles() const;
 
     /**
-     * Migrate all entries of one profile to another.
+     * Migrate all entries of one profile to another. This function does
+     * not honor the useProfiles() function, so you can migrate profiles
+     * even if their usage is not enabled.
      *
-     * @param from        The name of the old profile.
-     * @param to          The name of the new profile.
+     * @param oldName     The name of the old profile
+     * @param newName     The name of the new profile
      */
-    void migrateProfile(const QString &from, const QString &to);
+    void migrateProfile(const QString &oldName, const QString &newName);
 
     /**
-     * Migrate all entries of a list of profiles to other profiles.
+     * Remove a profile with all of its entries. This function does
+     * not honor the useProfiles() function, so you can remove profiles
+     * even if their usage is not enabled.
      *
-     * @param list        The list of profile pairs. The first entry
-     *                    is the "from" profile, the second one the
-     *                    "to" profile.
-     */
-    void migrateProfiles(const QList<QPair<QString, QString>> &list);
-
-    /**
-     * Remove a profile with all of its entries.
-     *
-     * @param name        The name of the profile.
+     * @param name        The name of the profile
      */
     void removeProfile(const QString &name);
 
-    /**
-     * Remove a list of profiles with all of their entries.
-     *
-     * @param list        The list of profile names.
-     */
-    void removeProfiles(const QStringList &list);
-
 Q_SIGNALS:
     /**
      * This signal is emitted when all entries of one profile was migrated
-     * to another one.
+     * to another one. There are two special marker for profiles. If the
+     * old name is '*', this means 'all profiles' and if the either the old
+     * or the new name is an empty thing, this means 'default profile'.
      *
-     * @param from        The old profile
-     * @param to          The new profile
+     * @param oldName     The name of the old profile
+     * @param newName     The name of the new profile
      */
-    void migratedProfile(const QString &from, const QString &to);
+    void profileMigrated(const QString &oldName, const QString &newName);
 
     /**
-     * This signal is emitted when a profile was removed.
+     * This signal is emitted when a profile is to be removed.
      *
      * @param profile     The removed profile
      */
-    void removedProfile(const QString &profile);
+    void profileRemoved(const QString &profile);
 
     /**
      * This signal is emitted when the active profile is about
