@@ -1,7 +1,7 @@
 /*
     Smb4K's container class for information about a share.
 
-    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2008-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -15,10 +15,10 @@
 
 // KDE includes
 #include "kiconthemes_version.h"
-#include <KI18n/KLocalizedString>
-#include <KIOCore/KIO/Global>
-#include <KIOCore/KMountPoint>
-#include <KIconThemes/KIconLoader>
+#include <KIO/Global>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KMountPoint>
 
 class Smb4KSharePrivate
 {
@@ -65,14 +65,14 @@ Smb4KShare::Smb4KShare(const QUrl &url)
     setShareIcon();
 }
 
-Smb4KShare::Smb4KShare(const Smb4KShare &s)
-    : Smb4KBasicNetworkItem(s)
+Smb4KShare::Smb4KShare(const Smb4KShare &share)
+    : Smb4KBasicNetworkItem(share)
     , d(new Smb4KSharePrivate)
 {
     //
     // Copy the private variables
     //
-    *d = *s.d;
+    *d = *share.d;
 
     //
     // Set the icon if necessary
@@ -497,3 +497,9 @@ void Smb4KShare::update(Smb4KShare *share)
         setHostIpAddress(share->hostIpAddress());
     }
 }
+
+Smb4KShare &Smb4KShare::operator=(const Smb4KShare &other)
+{
+    *d = *other.d;
+    return *this;
+}
