@@ -1,7 +1,7 @@
 /*
     Smb4K's container class for information about a share.
 
-    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2008-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -19,7 +19,7 @@
 #include <QtGlobal>
 
 // KDE includes
-#include <KCoreAddons/KUser>
+#include <KUser>
 
 // forward declarations
 class Smb4KAuthInfo;
@@ -456,6 +456,11 @@ public:
      */
     void update(Smb4KShare *share);
 
+    /**
+     * Copy assignment operator
+     */
+    Smb4KShare &operator=(const Smb4KShare &other);
+
 private:
     const QScopedPointer<Smb4KSharePrivate> d;
 
@@ -465,4 +470,6 @@ private:
     void setShareIcon();
 };
 
+Q_DECLARE_METATYPE(Smb4KShare)
+
 #endif
