@@ -1,7 +1,7 @@
 /*
     Smb4K's container class for information about a workgroup.
 
-    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2008-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -39,7 +39,7 @@ public:
      *
      * @param name            The name of the workgroup or domain.
      */
-    SMB4K_DEPRECATED explicit Smb4KWorkgroup(const QString &name);
+    explicit Smb4KWorkgroup(const QString &name);
 
     /**
      * The copy constructor. This constructor takes another Smb4KWorkgroup item
@@ -137,8 +137,15 @@ public:
      */
     void update(Smb4KWorkgroup *workgroup);
 
+    /**
+     * Copy assignment operator
+     */
+    Smb4KWorkgroup &operator=(const Smb4KWorkgroup &other);
+
 private:
     const QScopedPointer<Smb4KWorkgroupPrivate> d;
 };
 
+Q_DECLARE_METATYPE(Smb4KWorkgroup)
+
 #endif
