@@ -16,10 +16,10 @@
 #include <QUrl>
 
 // KDE includes
-#include <KAuth/KAuthHelperSupport>
-#include <KCoreAddons/KProcess>
-#include <KI18n/KLocalizedString>
-#include <KIOCore/KMountPoint>
+#include <KAuth/HelperSupport>
+#include <KLocalizedString>
+#include <KMountPoint>
+#include <KProcess>
 
 using namespace Smb4KGlobal;
 
