@@ -11,54 +11,78 @@
 #include "core/smb4kbookmark.h"
 #include "core/smb4kbookmarkhandler.h"
 #include "core/smb4kclient.h"
-#include "core/smb4kcustomoptionsmanager.h"
-#include "core/smb4kglobal.h"
 #include "core/smb4khost.h"
 #include "core/smb4kmounter.h"
+#include "core/smb4knotification.h"
 #include "core/smb4kprofilemanager.h"
 #include "core/smb4kshare.h"
 #include "core/smb4ksynchronizer.h"
 #include "core/smb4kworkgroup.h"
+#include "smb4k/smb4kcustomsettingseditor.h"
+#include "smb4k/smb4khomesuserdialog.h"
+#include "smb4k/smb4kpassworddialog.h"
+#include "smb4k/smb4kpreviewdialog.h"
+#include "smb4k/smb4kprintdialog.h"
+#include "smb4k/smb4ksynchronizationdialog.h"
+#include "smb4kbookmarkdialog.h"
+#include "smb4kbookmarkeditor.h"
 #include "smb4kbookmarkobject.h"
-#include "smb4kdeclarative_p.h"
+#include "smb4kmountdialog.h"
 #include "smb4knetworkobject.h"
 #include "smb4kprofileobject.h"
 
+//
 // Qt includes
 #include <QDebug>
+#include <QPointer>
 
 // KDE includes
-#include <KConfigWidgets/KConfigDialog>
-#include <KCoreAddons/KPluginFactory>
-#include <KCoreAddons/KPluginLoader>
+#include <KConfigDialog>
+#include <KMessageBox>
+#include <KPluginFactory>
+#include <KPluginMetaData>
+
+class Smb4KDeclarativePrivate
+{
+public:
+    QList<Smb4KNetworkObject *> workgroupObjects;
+    QList<Smb4KNetworkObject *> hostObjects;
+    QList<Smb4KNetworkObject *> shareObjects;
+    QList<Smb4KNetworkObject *> mountedObjects;
+    QList<Smb4KBookmarkObject *> bookmarkObjects;
+    QList<Smb4KBookmarkObject *> bookmarkCategoryObjects;
+    QList<Smb4KProfileObject *> profileObjects;
+    QList<NetworkItemPtr> requestQueue;
+    QPointer<Smb4KPasswordDialog> passwordDialog;
+    int timerId;
+};
 
 Smb4KDeclarative::Smb4KDeclarative(QObject *parent)
     : QObject(parent)
     , d(new Smb4KDeclarativePrivate)
 {
-    //
-    // Initialize the core
-    //
-    Smb4KGlobal::initCore(true, false);
+    d->passwordDialog = new Smb4KPasswordDialog();
+    d->timerId = 0;
 
-    //
-    // Connections
-    //
-    connect(Smb4KClient::self(), SIGNAL(workgroups()), this, SLOT(slotWorkgroupsListChanged()));
-    connect(Smb4KClient::self(), SIGNAL(hosts(WorkgroupPtr)), this, SLOT(slotHostsListChanged()));
-    connect(Smb4KClient::self(), SIGNAL(shares(HostPtr)), this, SLOT(slotSharesListChanged()));
-    connect(Smb4KClient::self(), SIGNAL(aboutToStart(NetworkItemPtr, int)), this, SIGNAL(busy()));
-    connect(Smb4KClient::self(), SIGNAL(finished(NetworkItemPtr, int)), this, SIGNAL(idle()));
+    Smb4KNotification::setComponentName(QStringLiteral("smb4k"));
 
-    connect(Smb4KMounter::self(), SIGNAL(mountedSharesListChanged()), this, SLOT(slotMountedSharesListChanged()));
-    connect(Smb4KMounter::self(), SIGNAL(aboutToStart(int)), this, SIGNAL(busy()));
-    connect(Smb4KMounter::self(), SIGNAL(finished(int)), this, SIGNAL(idle()));
+    connect(Smb4KClient::self(), &Smb4KClient::workgroups, this, &Smb4KDeclarative::slotWorkgroupsListChanged);
+    connect(Smb4KClient::self(), &Smb4KClient::hosts, this, &Smb4KDeclarative::slotHostsListChanged);
+    connect(Smb4KClient::self(), &Smb4KClient::shares, this, &Smb4KDeclarative::slotSharesListChanged);
+    connect(Smb4KClient::self(), &Smb4KClient::aboutToStart, this, &Smb4KDeclarative::busy);
+    connect(Smb4KClient::self(), &Smb4KClient::finished, this, &Smb4KDeclarative::idle);
+    connect(Smb4KClient::self(), &Smb4KClient::requestCredentials, this, &Smb4KDeclarative::slotCredentialsRequested);
 
-    connect(Smb4KBookmarkHandler::self(), SIGNAL(updated()), this, SLOT(slotBookmarksListChanged()));
+    connect(Smb4KMounter::self(), &Smb4KMounter::mountedSharesListChanged, this, &Smb4KDeclarative::slotMountedSharesListChanged);
+    connect(Smb4KMounter::self(), &Smb4KMounter::aboutToStart, this, &Smb4KDeclarative::busy);
+    connect(Smb4KMounter::self(), &Smb4KMounter::finished, this, &Smb4KDeclarative::idle);
+    connect(Smb4KMounter::self(), &Smb4KMounter::requestCredentials, this, &Smb4KDeclarative::slotCredentialsRequested);
 
-    connect(Smb4KProfileManager::self(), SIGNAL(profilesListChanged(QStringList)), this, SLOT(slotProfilesListChanged(QStringList)));
-    connect(Smb4KProfileManager::self(), SIGNAL(activeProfileChanged(QString)), this, SLOT(slotActiveProfileChanged(QString)));
-    connect(Smb4KProfileManager::self(), SIGNAL(profileUsageChanged(bool)), this, SLOT(slotProfileUsageChanged(bool)));
+    connect(Smb4KBookmarkHandler::self(), &Smb4KBookmarkHandler::updated, this, &Smb4KDeclarative::slotBookmarksListChanged);
+
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profilesListChanged, this, &Smb4KDeclarative::slotProfilesListChanged);
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::activeProfileChanged, this, &Smb4KDeclarative::slotActiveProfileChanged);
+    connect(Smb4KProfileManager::self(), &Smb4KProfileManager::profileUsageChanged, this, &Smb4KDeclarative::slotProfileUsageChanged);
 
     //
     // Do the initial loading of items
@@ -220,7 +244,8 @@ Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem(const QUrl &url, int type)
 
 void Smb4KDeclarative::openMountDialog()
 {
-    Smb4KMounter::self()->openMountDialog();
+    QPointer<Smb4KMountDialog> mountDialog = new Smb4KMountDialog();
+    mountDialog->open();
 }
 
 void Smb4KDeclarative::mountShare(Smb4KNetworkObject *object)
@@ -229,6 +254,24 @@ void Smb4KDeclarative::mountShare(Smb4KNetworkObject *object)
         SharePtr share = Smb4KGlobal::findShare(object->url(), object->workgroupName());
 
         if (share) {
+            if (share->isHomesShare()) {
+                QPointer<Smb4KHomesUserDialog> homesUserDialog = new Smb4KHomesUserDialog();
+                bool proceed = false;
+
+                if (homesUserDialog->setShare(share)) {
+                    // We want to get a return value here, so we use exec()
+                    if (homesUserDialog->exec() == QDialog::Accepted) {
+                        proceed = true;
+                    }
+                }
+
+                delete homesUserDialog;
+
+                if (!proceed) {
+                    return;
+                }
+            }
+
             Smb4KMounter::self()->mountShare(share);
         }
     }
@@ -287,7 +330,13 @@ void Smb4KDeclarative::print(Smb4KNetworkObject *object)
         SharePtr printer = Smb4KGlobal::findShare(object->url(), object->workgroupName());
 
         if (printer) {
-            Smb4KClient::self()->openPrintDialog(printer);
+            QPointer<Smb4KPrintDialog> printDialog = new Smb4KPrintDialog();
+
+            if (printDialog->setPrinterShare(printer)) {
+                printDialog->open();
+            } else {
+                delete printDialog;
+            }
         }
     }
 }
@@ -310,7 +359,13 @@ void Smb4KDeclarative::addBookmark(Smb4KNetworkObject *object)
         }
 
         if (!shares.isEmpty()) {
-            Smb4KBookmarkHandler::self()->addBookmarks(shares);
+            QPointer<Smb4KBookmarkDialog> bookmarkDialog = new Smb4KBookmarkDialog();
+
+            if (bookmarkDialog->setShares(shares)) {
+                bookmarkDialog->open();
+            } else {
+                delete bookmarkDialog;
+            }
         }
     }
 }
@@ -331,7 +386,8 @@ void Smb4KDeclarative::removeBookmark(Smb4KBookmarkObject *object)
 
 void Smb4KDeclarative::editBookmarks()
 {
-    Smb4KBookmarkHandler::self()->editBookmarks();
+    QPointer<Smb4KBookmarkEditor> bookmarkEditor = new Smb4KBookmarkEditor();
+    bookmarkEditor->open();
 }
 
 void Smb4KDeclarative::synchronize(Smb4KNetworkObject *object)
@@ -339,7 +395,12 @@ void Smb4KDeclarative::synchronize(Smb4KNetworkObject *object)
     if (object && object->type() == Smb4KNetworkObject::Share) {
         for (const SharePtr &share : Smb4KGlobal::mountedSharesList()) {
             if (share->url() == object->url()) {
-                Smb4KSynchronizer::self()->synchronize(share);
+                QPointer<Smb4KSynchronizationDialog> synchronizationDialog = new Smb4KSynchronizationDialog();
+                if (synchronizationDialog->setShare(share)) {
+                    synchronizationDialog->open();
+                } else {
+                    delete synchronizationDialog;
+                }
             }
         }
     }
@@ -348,14 +409,14 @@ void Smb4KDeclarative::synchronize(Smb4KNetworkObject *object)
 void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
 {
     if (object) {
+        NetworkItemPtr networkItem;
+
         switch (object->type()) {
         case Smb4KNetworkObject::Host: {
             for (const HostPtr &host : Smb4KGlobal::hostsList()) {
                 if (host->url() == object->url()) {
-                    Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(host);
+                    networkItem = host;
                     break;
-                } else {
-                    continue;
                 }
             }
             break;
@@ -363,10 +424,8 @@ void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
         case Smb4KNetworkObject::Share: {
             for (const SharePtr &share : Smb4KGlobal::sharesList()) {
                 if (share->url() == object->url()) {
-                    Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(share);
+                    networkItem = share;
                     break;
-                } else {
-                    continue;
                 }
             }
             break;
@@ -375,6 +434,15 @@ void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
             break;
         }
         }
+
+        if (!networkItem.isNull()) {
+            QPointer<Smb4KCustomSettingsEditor> customSettingsEditor = new Smb4KCustomSettingsEditor();
+            if (customSettingsEditor->setNetworkItem(networkItem)) {
+                customSettingsEditor->open();
+            } else {
+                delete customSettingsEditor;
+            }
+        }
     }
 }
 
@@ -430,7 +498,13 @@ void Smb4KDeclarative::preview(Smb4KNetworkObject *object)
         SharePtr share = Smb4KGlobal::findShare(object->url(), object->workgroupName());
 
         if (share) {
-            Smb4KClient::self()->openPreviewDialog(share);
+            QPointer<Smb4KPreviewDialog> previewDialog = new Smb4KPreviewDialog();
+
+            if (previewDialog->setShare(share)) {
+                previewDialog->open();
+            } else {
+                delete previewDialog;
+            }
         }
     }
 }
@@ -448,11 +522,11 @@ void Smb4KDeclarative::openConfigurationDialog()
     //
     // If the dialog does not exist, load and show it:
     //
-    KPluginLoader loader(QStringLiteral("smb4kconfigdialog"), this);
-    KPluginFactory *configFactory = loader.factory();
+    KPluginMetaData metaData(QStringLiteral("smb4kconfigdialog"));
+    KPluginFactory::Result<KPluginFactory> result = KPluginFactory::loadFactory(metaData);
 
-    if (configFactory) {
-        KConfigDialog *dlg = configFactory->create<KConfigDialog>();
+    if (result.errorReason == KPluginFactory::NO_PLUGIN_ERROR) {
+        QPointer<KConfigDialog> dlg = result.plugin->create<KConfigDialog>();
 
         if (dlg) {
             dlg->setObjectName(QStringLiteral("Smb4KConfigDialog"));
@@ -461,6 +535,24 @@ void Smb4KDeclarative::openConfigurationDialog()
     }
 }
 
+void Smb4KDeclarative::timerEvent(QTimerEvent *event)
+{
+    Q_UNUSED(event);
+
+    if (!d->requestQueue.isEmpty()) {
+        if (!d->passwordDialog->isVisible()) {
+            NetworkItemPtr networkItem = d->requestQueue.takeFirst();
+
+            if (networkItem && d->passwordDialog->setNetworkItem(networkItem)) {
+                d->passwordDialog->show();
+            }
+        }
+    } else {
+        killTimer(d->timerId);
+        d->timerId = 0;
+    }
+}
+
 void Smb4KDeclarative::slotWorkgroupsListChanged()
 {
     qDeleteAll(d->workgroupObjects);
@@ -517,7 +609,7 @@ void Smb4KDeclarative::slotBookmarksListChanged()
     qDeleteAll(d->bookmarkCategoryObjects);
     d->bookmarkCategoryObjects.clear();
 
-    QList<BookmarkPtr> bookmarksList = Smb4KBookmarkHandler::self()->bookmarksList();
+    QList<BookmarkPtr> bookmarksList = Smb4KBookmarkHandler::self()->bookmarkList();
     QStringList categoriesList = Smb4KBookmarkHandler::self()->categoryList();
 
     for (const BookmarkPtr &bookmark : qAsConst(bookmarksList)) {
@@ -569,3 +661,12 @@ void Smb4KDeclarative::slotProfileUsageChanged(bool /*use*/)
 {
     Q_EMIT profileUsageChanged();
 }
+
+void Smb4KDeclarative::slotCredentialsRequested(const NetworkItemPtr &networkItem)
+{
+    d->requestQueue.append(networkItem);
+
+    if (d->timerId == 0) {
+        d->timerId = startTimer(500);
+    }
+}
