@@ -1,12 +1,13 @@
 /*
     Main file of the Smb4K program.
 
-    SPDX-FileCopyrightText: 2003-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2003-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // application specific includes
-#include "core/smb4kglobal.h"
+#include "core/smb4kclient.h"
+#include "core/smb4kmounter.h"
 #include "core/smb4ksettings.h"
 #include "smb4kmainwindow.h"
 
@@ -15,11 +16,11 @@
 #include <QString>
 
 // KDE includes
-#include <KCoreAddons/KAboutData>
-#include <KCrash/KCrash>
-#include <KDBusAddons/KDBusService>
-#include <KI18n/KLocalizedString>
-#include <KWindowSystem/KWindowSystem>
+#include <KAboutData>
+#include <KCrash>
+#include <KDBusService>
+#include <KLocalizedString>
+#include <KWindowSystem>
 #include <kwindowsystem_version.h>
 
 #include <smb4k_version.h>
@@ -28,9 +29,11 @@ using namespace Smb4KGlobal;
 
 int main(int argc, char **argv)
 {
+#if QT_VERSION <= QT_VERSION_CHECK(6, 0, 0)
     // Set attributes
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
 
     // Create the application
     QApplication app(argc, argv);
@@ -44,7 +47,7 @@ int main(int argc, char **argv)
                          QStringLiteral(SMB4K_VERSION_STRING),
                          i18n("Advanced network neighborhood browser and Samba share mounting utility"),
                          KAboutLicense::GPL_V2,
-                         i18n("\u00A9 2003-2023 Alexander Reinholdt"),
+                         i18n("\u00A9 2003-2024 Alexander Reinholdt"),
                          QString(),
                          QStringLiteral("https://smb4k.sourceforge.io"));
 
@@ -60,15 +63,9 @@ int main(int argc, char **argv)
     // money
     aboutData.addCredit(i18n("Wolfgang Geisendörfer"), i18n("Donator"), QStringLiteral("wdm-lin@gmx.net"));
 
-    // Register about data
+    // Set application about data
     KAboutData::setApplicationData(aboutData);
 
-    // Now add the data to the application
-    app.setApplicationName(aboutData.componentName());
-    app.setApplicationDisplayName(aboutData.displayName());
-    app.setOrganizationDomain(aboutData.organizationDomain());
-    app.setApplicationVersion(aboutData.version());
-
     // We need to set this property because otherwise the application
     // will quit when it is embedded into the system tray, the main window
     // is hidden and the last window that was opened through the system
@@ -82,18 +79,18 @@ int main(int argc, char **argv)
     Smb4KMainWindow *mainWindow = new Smb4KMainWindow();
     mainWindow->setVisible(!Smb4KSettings::startMainWindowDocked());
 
-    // Initialize the core. Use a busy cursor.
-    initCore(true);
+    // FIXME: Move this to the main window?
+    // Start scanning the network neighborhood and remounting shares.
+    Smb4KClient::self()->start();
+    Smb4KMounter::self()->start();
 
     // Unique application
     const KDBusService service(KDBusService::Unique);
 
     QObject::connect(&service, &KDBusService::activateRequested, mainWindow, [mainWindow](const QStringList & /*args*/, const QString & /*workingDir*/) {
         if (mainWindow->isVisible()) {
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 91, 0)
             KWindowSystem::updateStartupId(mainWindow->windowHandle());
             KWindowSystem::activateWindow(mainWindow->windowHandle());
-#endif
         } else {
             mainWindow->setVisible(true);
         }
