@@ -34,7 +34,7 @@ Smb4KBookmarkMenu::Smb4KBookmarkMenu(int type, QObject *parent)
     m_mountActions = new QActionGroup(menu());
 
     m_editBookmarks = new QAction(KDE::icon(QStringLiteral("bookmarks-organize")), i18n("&Edit Bookmarks"), menu());
-    m_editBookmarks->setEnabled(!Smb4KBookmarkHandler::self()->bookmarksList().isEmpty());
+    m_editBookmarks->setEnabled(!Smb4KBookmarkHandler::self()->bookmarkList().isEmpty());
     connect(m_editBookmarks, SIGNAL(triggered(bool)), SLOT(slotEditActionTriggered(bool)));
     addAction(m_editBookmarks);
 
@@ -52,7 +52,7 @@ Smb4KBookmarkMenu::Smb4KBookmarkMenu(int type, QObject *parent)
     m_mountActions->addAction(m_toplevelMount);
 
     m_separator = addSeparator();
-    m_separator->setVisible(!Smb4KBookmarkHandler::self()->bookmarksList().isEmpty());
+    m_separator->setVisible(!Smb4KBookmarkHandler::self()->bookmarkList().isEmpty());
 
     loadBookmarks();
     adjustMountActions();
@@ -101,7 +101,7 @@ void Smb4KBookmarkMenu::loadBookmarks()
             addAction(categoryMenu);
             m_categories->addAction(categoryMenu);
 
-            topLevelActions[QStringLiteral("00_")+category] = categoryMenu;
+            topLevelActions[QStringLiteral("00_") + category] = categoryMenu;
 
             QAction *categoryMount = new QAction(KDE::icon(QStringLiteral("media-mount")), i18n("Mount Bookmarks"), categoryMenu->menu());
             categoryMount->setData(category);
@@ -115,7 +115,7 @@ void Smb4KBookmarkMenu::loadBookmarks()
         }
 
         QMap<QString, QAction *> actionMap;
-        QList<BookmarkPtr> categoryBookmarks = Smb4KBookmarkHandler::self()->bookmarksList(category);
+        QList<BookmarkPtr> categoryBookmarks = Smb4KBookmarkHandler::self()->bookmarkList(category);
 
         for (const BookmarkPtr &bookmark : qAsConst(categoryBookmarks)) {
             QAction *bookmarkAction = new QAction(categoryMenu->menu());
@@ -150,7 +150,7 @@ void Smb4KBookmarkMenu::loadBookmarks()
             if (!category.isEmpty()) {
                 actionMap[displayName] = bookmarkAction;
             } else {
-                topLevelActions[QStringLiteral("01_")+displayName] = bookmarkAction;
+                topLevelActions[QStringLiteral("01_") + displayName] = bookmarkAction;
             }
         }
 
@@ -173,8 +173,8 @@ void Smb4KBookmarkMenu::loadBookmarks()
 
     adjustMountActions();
 
-    m_editBookmarks->setEnabled(!Smb4KBookmarkHandler::self()->bookmarksList().isEmpty());
-    m_separator->setVisible(!Smb4KBookmarkHandler::self()->bookmarksList().isEmpty());
+    m_editBookmarks->setEnabled(!Smb4KBookmarkHandler::self()->bookmarkList().isEmpty());
+    m_separator->setVisible(!Smb4KBookmarkHandler::self()->bookmarkList().isEmpty());
 
     menu()->update();
 }
@@ -186,7 +186,7 @@ void Smb4KBookmarkMenu::setBookmarkActionEnabled(bool enable)
 
 void Smb4KBookmarkMenu::adjustMountActions()
 {
-    QList<BookmarkPtr> toplevelBookmarks = Smb4KBookmarkHandler::self()->bookmarksList(QStringLiteral(""));
+    QList<BookmarkPtr> toplevelBookmarks = Smb4KBookmarkHandler::self()->bookmarkList(QStringLiteral(""));
 
     if (!toplevelBookmarks.isEmpty()) {
         int mountedBookmarks = 0;
@@ -214,7 +214,7 @@ void Smb4KBookmarkMenu::adjustMountActions()
     int mountedBookmarks = 0;
 
     for (const QString &category : qAsConst(allCategories)) {
-        QList<BookmarkPtr> bookmarks = Smb4KBookmarkHandler::self()->bookmarksList(category);
+        QList<BookmarkPtr> bookmarks = Smb4KBookmarkHandler::self()->bookmarkList(category);
 
         for (const BookmarkPtr &bookmark : bookmarks) {
             QList<SharePtr> mountedShares = findShareByUrl(bookmark->url());
@@ -247,7 +247,9 @@ void Smb4KBookmarkMenu::adjustMountActions()
 void Smb4KBookmarkMenu::slotEditActionTriggered(bool checked)
 {
     Q_UNUSED(checked);
-    Smb4KBookmarkHandler::self()->editBookmarks();
+
+    QPointer<Smb4KBookmarkEditor> bookmarkEditor = new Smb4KBookmarkEditor(menu());
+    bookmarkEditor->open();
 }
 
 void Smb4KBookmarkMenu::slotAddActionTriggered(bool /*checked*/)
@@ -260,9 +262,9 @@ void Smb4KBookmarkMenu::slotMountActionTriggered(QAction *action)
     QList<BookmarkPtr> bookmarks;
 
     if (action == m_toplevelMount) {
-        bookmarks = Smb4KBookmarkHandler::self()->bookmarksList(QStringLiteral(""));
+        bookmarks = Smb4KBookmarkHandler::self()->bookmarkList(QStringLiteral(""));
     } else {
-        bookmarks = Smb4KBookmarkHandler::self()->bookmarksList(action->data().toString());
+        bookmarks = Smb4KBookmarkHandler::self()->bookmarkList(action->data().toString());
     }
 
     QList<SharePtr> mounts;
