@@ -1,7 +1,7 @@
 /*
     The configuration page for the authentication settings of Smb4K
 
-    SPDX-FileCopyrightText: 2003-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2003-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -12,7 +12,10 @@
 #include "core/smb4kauthinfo.h"
 
 // Qt includes
+#include <QCheckBox>
 #include <QList>
+#include <QListWidget>
+#include <QPushButton>
 #include <QWidget>
 
 // Forward declarations
@@ -156,8 +159,18 @@ protected Q_SLOTS:
     void slotWalletItemDoubleClicked(QListWidgetItem *item);
 
 private:
+    QWidget *m_walletEntriesEditor;
+    QListWidget *m_walletEntriesWidget;
+    QPushButton *m_loadButton;
+    QPushButton *m_saveButton;
+    QPushButton *m_editButton;
+    QPushButton *m_removeButton;
+    QPushButton *m_clearButton;
+    QPushButton *m_resetButton;
+    QCheckBox *m_useDefaultLogin;
     QList<Smb4KAuthInfo *> m_entriesList;
-    bool m_entries_loaded;
+    // FIXME: Do we need this at all?
+    bool m_entriesLoaded;
 };
 
 #endif
