@@ -1,7 +1,7 @@
 /*
     The configuration page for the profiles
 
-    SPDX-FileCopyrightText: 2014-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2014-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -9,12 +9,16 @@
 #define SMB4KCONFIGPAGEPROFILES_H
 
 // Qt includes
+#include <QCheckBox>
 #include <QList>
 #include <QPair>
 #include <QWidget>
 
 // KDE includes
-#include <KWidgetsAddons/KEditListWidget>
+#include <KEditListWidget>
+
+// forward declarations
+struct ProfileContainer;
 
 class Smb4KConfigPageProfiles : public QWidget
 {
@@ -36,15 +40,24 @@ public:
      */
     void applyChanges();
 
+    /**
+     * Returns TRUE if the list of profiles changed and FALSE otherwise.
+     */
+    bool profilesChanged() const;
+
 protected Q_SLOTS:
-    void slotEnableWidget(int state);
-    void slotProfileRemoved(const QString &name);
+    void slotProfileUsageChanged(bool checked);
+    void slotProfileAdded(const QString &text);
+    void slotProfileRemoved(const QString &text);
     void slotProfileChanged();
 
 private:
-    KEditListWidget *m_profiles;
-    QList<QPair<QString, QString>> m_renamed;
-    QStringList m_removed;
+    QCheckBox *m_useProfiles;
+    QCheckBox *m_transferToFirstProfile;
+    QCheckBox *m_makeAllDataAvailable;
+    KEditListWidget *m_profilesWidget;
+    QList<ProfileContainer> m_profiles;
+    bool m_profilesChanged;
 };
 
 #endif
