@@ -1,45 +1,50 @@
 /*
     The network neighborhood browser dock widget
 
-    SPDX-FileCopyrightText: 2018-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2018-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // application specific includes
 #include "smb4knetworkbrowserdockwidget.h"
-#include "core/smb4kbookmarkhandler.h"
 #include "core/smb4kclient.h"
-#include "core/smb4kcustomoptionsmanager.h"
 #include "core/smb4khost.h"
 #include "core/smb4kmounter.h"
 #include "core/smb4ksettings.h"
 #include "core/smb4kshare.h"
 #include "core/smb4kwalletmanager.h"
 #include "core/smb4kworkgroup.h"
+#include "smb4kbookmarkdialog.h"
+#include "smb4kcustomsettingseditor.h"
+#include "smb4khomesuserdialog.h"
+#include "smb4kmountdialog.h"
+#include "smb4knetworkbrowser.h"
 #include "smb4knetworkbrowseritem.h"
+#include "smb4knetworksearchtoolbar.h"
+#include "smb4kpassworddialog.h"
+#include "smb4kpreviewdialog.h"
+#include "smb4kprintdialog.h"
 #include "smb4ktooltip.h"
 
 // Qt includes
 #include <QApplication>
 #include <QHeaderView>
 #include <QMenu>
+#include <QPointer>
 #include <QTreeWidgetItemIterator>
 #include <QVBoxLayout>
 
 // KDE includes
-#include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
-#include <KWidgetsAddons/KDualAction>
-#include <KWidgetsAddons/KGuiItem>
+#include <KDualAction>
+#include <KGuiItem>
+#include <KIconLoader>
+#include <KLocalizedString>
 
 using namespace Smb4KGlobal;
 
 Smb4KNetworkBrowserDockWidget::Smb4KNetworkBrowserDockWidget(const QString &title, QWidget *parent)
     : QDockWidget(title, parent)
 {
-    //
-    // The network browser widget
-    //
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainWidgetLayout = new QVBoxLayout(mainWidget);
     mainWidgetLayout->setContentsMargins(0, 0, 0, 0);
@@ -53,55 +58,34 @@ Smb4KNetworkBrowserDockWidget::Smb4KNetworkBrowserDockWidget(const QString &titl
 
     setWidget(mainWidget);
 
-    //
-    // The action collection
-    //
     m_actionCollection = new KActionCollection(this);
-
-    //
-    // The context menu
-    //
     m_contextMenu = new KActionMenu(this);
-
-    //
-    // Search underway?
-    //
     m_searchRunning = false;
 
-    //
-    // Set up the actions
-    //
     setupActions();
-
-    //
-    // Load the settings
-    //
     loadSettings();
 
-    //
-    // Connections
-    //
-    connect(m_networkBrowser, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenuRequested(QPoint)));
-    connect(m_networkBrowser, SIGNAL(itemActivated(QTreeWidgetItem *, int)), this, SLOT(slotItemActivated(QTreeWidgetItem *, int)));
-    connect(m_networkBrowser, SIGNAL(itemSelectionChanged()), this, SLOT(slotItemSelectionChanged()));
+    connect(m_networkBrowser, &Smb4KNetworkBrowser::customContextMenuRequested, this, &Smb4KNetworkBrowserDockWidget::slotContextMenuRequested);
+    connect(m_networkBrowser, &Smb4KNetworkBrowser::itemActivated, this, &Smb4KNetworkBrowserDockWidget::slotItemActivated);
+    connect(m_networkBrowser, &Smb4KNetworkBrowser::itemSelectionChanged, this, &Smb4KNetworkBrowserDockWidget::slotItemSelectionChanged);
 
-    connect(m_searchToolBar, SIGNAL(closeSearchBar()), this, SLOT(slotHideSearchToolBar()));
-    connect(m_searchToolBar, SIGNAL(search(QString)), this, SLOT(slotPerformSearch(QString)));
-    connect(m_searchToolBar, SIGNAL(abort()), this, SLOT(slotStopSearch()));
-    connect(m_searchToolBar, SIGNAL(jumpToResult(QString)), this, SLOT(slotJumpToResult(QString)));
-    connect(m_searchToolBar, SIGNAL(clearSearchResults()), this, SLOT(slotClearSearchResults()));
+    connect(m_searchToolBar, &Smb4KNetworkSearchToolBar::closeSearchBar, this, &Smb4KNetworkBrowserDockWidget::slotHideSearchToolBar);
+    connect(m_searchToolBar, &Smb4KNetworkSearchToolBar::search, this, &Smb4KNetworkBrowserDockWidget::slotPerformSearch);
+    connect(m_searchToolBar, &Smb4KNetworkSearchToolBar::abort, this, &Smb4KNetworkBrowserDockWidget::slotStopSearch);
+    connect(m_searchToolBar, &Smb4KNetworkSearchToolBar::jumpToResult, this, &Smb4KNetworkBrowserDockWidget::slotJumpToResult);
+    connect(m_searchToolBar, &Smb4KNetworkSearchToolBar::clearSearchResults, this, &Smb4KNetworkBrowserDockWidget::slotClearSearchResults);
 
-    connect(Smb4KClient::self(), SIGNAL(aboutToStart(NetworkItemPtr, int)), this, SLOT(slotClientAboutToStart(NetworkItemPtr, int)));
-    connect(Smb4KClient::self(), SIGNAL(finished(NetworkItemPtr, int)), this, SLOT(slotClientFinished(NetworkItemPtr, int)));
-    connect(Smb4KClient::self(), SIGNAL(workgroups()), this, SLOT(slotWorkgroups()));
-    connect(Smb4KClient::self(), SIGNAL(hosts(WorkgroupPtr)), this, SLOT(slotWorkgroupMembers(WorkgroupPtr)));
-    connect(Smb4KClient::self(), SIGNAL(shares(HostPtr)), this, SLOT(slotShares(HostPtr)));
-    connect(Smb4KClient::self(), SIGNAL(searchResults(QList<SharePtr>)), this, SLOT(slotSearchResults(QList<SharePtr>)));
+    connect(Smb4KClient::self(), &Smb4KClient::aboutToStart, this, &Smb4KNetworkBrowserDockWidget::slotClientAboutToStart);
+    connect(Smb4KClient::self(), &Smb4KClient::finished, this, &Smb4KNetworkBrowserDockWidget::slotClientFinished);
+    connect(Smb4KClient::self(), &Smb4KClient::workgroups, this, &Smb4KNetworkBrowserDockWidget::slotWorkgroups);
+    connect(Smb4KClient::self(), &Smb4KClient::hosts, this, &Smb4KNetworkBrowserDockWidget::slotWorkgroupMembers);
+    connect(Smb4KClient::self(), &Smb4KClient::shares, this, &Smb4KNetworkBrowserDockWidget::slotShares);
+    connect(Smb4KClient::self(), &Smb4KClient::searchResults, this, &Smb4KNetworkBrowserDockWidget::slotSearchResults);
 
-    connect(Smb4KMounter::self(), SIGNAL(mounted(SharePtr)), this, SLOT(slotShareMounted(SharePtr)));
-    connect(Smb4KMounter::self(), SIGNAL(unmounted(SharePtr)), this, SLOT(slotShareUnmounted(SharePtr)));
-    connect(Smb4KMounter::self(), SIGNAL(aboutToStart(int)), this, SLOT(slotMounterAboutToStart(int)));
-    connect(Smb4KMounter::self(), SIGNAL(finished(int)), this, SLOT(slotMounterFinished(int)));
+    connect(Smb4KMounter::self(), &Smb4KMounter::mounted, this, &Smb4KNetworkBrowserDockWidget::slotShareMounted);
+    connect(Smb4KMounter::self(), &Smb4KMounter::unmounted, this, &Smb4KNetworkBrowserDockWidget::slotShareUnmounted);
+    connect(Smb4KMounter::self(), &Smb4KMounter::aboutToStart, this, &Smb4KNetworkBrowserDockWidget::slotMounterAboutToStart);
+    connect(Smb4KMounter::self(), &Smb4KMounter::finished, this, &Smb4KNetworkBrowserDockWidget::slotMounterFinished);
 }
 
 Smb4KNetworkBrowserDockWidget::~Smb4KNetworkBrowserDockWidget()
@@ -121,7 +105,7 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     rescanAbortAction->setAutoToggle(false);
     rescanAbortAction->setEnabled(true);
 
-    connect(rescanAbortAction, SIGNAL(triggered(bool)), this, SLOT(slotRescanAbortActionTriggered(bool)));
+    connect(rescanAbortAction, &KDualAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotRescanAbortActionTriggered);
 
     m_actionCollection->addAction(QStringLiteral("rescan_abort_action"), rescanAbortAction);
     m_actionCollection->setDefaultShortcut(rescanAbortAction, QKeySequence::Refresh);
@@ -131,7 +115,7 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     //
     QAction *searchAction = new QAction(KDE::icon(QStringLiteral("search")), i18n("&Search"), this);
 
-    connect(searchAction, SIGNAL(triggered(bool)), this, SLOT(slotShowSearchToolBar()));
+    connect(searchAction, &QAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotShowSearchToolBar);
 
     m_actionCollection->addAction(QStringLiteral("search_action"), searchAction);
     m_actionCollection->setDefaultShortcut(searchAction, QKeySequence::Find);
@@ -150,10 +134,10 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     QAction *bookmarkAction = new QAction(KDE::icon(QStringLiteral("bookmark-new")), i18n("Add &Bookmark"), this);
     bookmarkAction->setEnabled(false);
 
-    connect(bookmarkAction, SIGNAL(triggered(bool)), this, SLOT(slotAddBookmark(bool)));
+    connect(bookmarkAction, &QAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotAddBookmark);
 
     m_actionCollection->addAction(QStringLiteral("bookmark_action"), bookmarkAction);
-    m_actionCollection->setDefaultShortcut(bookmarkAction, QKeySequence(Qt::CTRL + Qt::Key_B));
+    m_actionCollection->setDefaultShortcut(bookmarkAction, QKeySequence(i18n("Ctrl+B")));
 
     //
     // Add custom options action
@@ -161,10 +145,10 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     QAction *customAction = new QAction(KDE::icon(QStringLiteral("settings-configure")), i18n("Add &Custom Settings"), this);
     customAction->setEnabled(false);
 
-    connect(customAction, SIGNAL(triggered(bool)), this, SLOT(slotAddCustomSettings(bool)));
+    connect(customAction, &QAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotAddCustomSettings);
 
     m_actionCollection->addAction(QStringLiteral("custom_action"), customAction);
-    m_actionCollection->setDefaultShortcut(customAction, QKeySequence(Qt::CTRL + Qt::Key_C));
+    m_actionCollection->setDefaultShortcut(customAction, QKeySequence(i18n("Ctrl+C")));
 
     //
     // Mount dialog action
@@ -173,10 +157,10 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
         new QAction(KDE::icon(QStringLiteral("view-form"), QStringList(QStringLiteral("emblem-mounted"))), i18n("&Open Mount Dialog"), this);
     manualAction->setEnabled(true);
 
-    connect(manualAction, SIGNAL(triggered(bool)), this, SLOT(slotMountManually(bool)));
+    connect(manualAction, &QAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotMountManually);
 
     m_actionCollection->addAction(QStringLiteral("mount_manually_action"), manualAction);
-    m_actionCollection->setDefaultShortcut(manualAction, QKeySequence(Qt::CTRL + Qt::Key_O));
+    m_actionCollection->setDefaultShortcut(manualAction, QKeySequence(i18n("Ctrl+O")));
 
     //
     // Separator
@@ -192,10 +176,10 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     QAction *authAction = new QAction(KDE::icon(QStringLiteral("dialog-password")), i18n("Au&thentication"), this);
     authAction->setEnabled(false);
 
-    connect(authAction, SIGNAL(triggered(bool)), this, SLOT(slotAuthentication(bool)));
+    connect(authAction, &QAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotAuthentication);
 
     m_actionCollection->addAction(QStringLiteral("authentication_action"), authAction);
-    m_actionCollection->setDefaultShortcut(authAction, QKeySequence(Qt::CTRL + Qt::Key_T));
+    m_actionCollection->setDefaultShortcut(authAction, QKeySequence(i18n("Ctrl+T")));
 
     //
     // Preview action
@@ -203,10 +187,10 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     QAction *previewAction = new QAction(KDE::icon(QStringLiteral("view-list-icons")), i18n("Pre&view"), this);
     previewAction->setEnabled(false);
 
-    connect(previewAction, SIGNAL(triggered(bool)), this, SLOT(slotPreview(bool)));
+    connect(previewAction, &QAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotPreview);
 
     m_actionCollection->addAction(QStringLiteral("preview_action"), previewAction);
-    m_actionCollection->setDefaultShortcut(previewAction, QKeySequence(Qt::CTRL + Qt::Key_V));
+    m_actionCollection->setDefaultShortcut(previewAction, QKeySequence(i18n("Ctrl+V")));
 
     //
     // Print action
@@ -214,10 +198,10 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     QAction *printAction = new QAction(KDE::icon(QStringLiteral("printer")), i18n("&Print File"), this);
     printAction->setEnabled(false);
 
-    connect(printAction, SIGNAL(triggered(bool)), this, SLOT(slotPrint(bool)));
+    connect(printAction, &QAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotPrint);
 
     m_actionCollection->addAction(QStringLiteral("print_action"), printAction);
-    m_actionCollection->setDefaultShortcut(printAction, QKeySequence(Qt::CTRL + Qt::Key_P));
+    m_actionCollection->setDefaultShortcut(printAction, QKeySequence(i18n("Ctrl+P")));
 
     //
     // Mount/unmount action
@@ -231,11 +215,11 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     mountAction->setAutoToggle(false);
     mountAction->setEnabled(false);
 
-    connect(mountAction, SIGNAL(triggered(bool)), this, SLOT(slotMountActionTriggered(bool)));
-    connect(mountAction, SIGNAL(activeChanged(bool)), this, SLOT(slotMountActionChanged(bool)));
+    connect(mountAction, &KDualAction::triggered, this, &Smb4KNetworkBrowserDockWidget::slotMountActionTriggered);
+    connect(mountAction, &KDualAction::activeChanged, this, &Smb4KNetworkBrowserDockWidget::slotMountActionChanged);
 
     m_actionCollection->addAction(QStringLiteral("mount_action"), mountAction);
-    m_actionCollection->setDefaultShortcut(mountAction, QKeySequence(Qt::CTRL + Qt::Key_M));
+    m_actionCollection->setDefaultShortcut(mountAction, QKeySequence(i18n("Ctrl+M")));
 
     //
     // Plug the actions into the context menu
@@ -262,31 +246,31 @@ void Smb4KNetworkBrowserDockWidget::loadSettings()
     m_networkBrowser->setColumnHidden(Smb4KNetworkBrowser::Type, !Smb4KSettings::showType());
     m_networkBrowser->setColumnHidden(Smb4KNetworkBrowser::Comment, !Smb4KSettings::showComment());
 
-    //
-    // Load and apply the positions of the columns
-    //
-    KConfigGroup configGroup(Smb4KSettings::self()->config(), "NetworkBrowserPart");
+    KConfigGroup configGroup(Smb4KSettings::self()->config(), QStringLiteral("NetworkBrowserPart"));
 
-    QMap<int, int> map;
-    map.insert(configGroup.readEntry("ColumnPositionNetwork", (int)Smb4KNetworkBrowser::Network), Smb4KNetworkBrowser::Network);
-    map.insert(configGroup.readEntry("ColumnPositionType", (int)Smb4KNetworkBrowser::Type), Smb4KNetworkBrowser::Type);
-    map.insert(configGroup.readEntry("ColumnPositionIP", (int)Smb4KNetworkBrowser::IP), Smb4KNetworkBrowser::IP);
-    map.insert(configGroup.readEntry("ColumnPositionComment", (int)Smb4KNetworkBrowser::Comment), Smb4KNetworkBrowser::Comment);
+    if (configGroup.exists()) {
+        QMap<int, int> map;
+        map.insert(configGroup.readEntry("ColumnPositionNetwork", (int)Smb4KNetworkBrowser::Network), Smb4KNetworkBrowser::Network);
+        map.insert(configGroup.readEntry("ColumnPositionType", (int)Smb4KNetworkBrowser::Type), Smb4KNetworkBrowser::Type);
+        map.insert(configGroup.readEntry("ColumnPositionIP", (int)Smb4KNetworkBrowser::IP), Smb4KNetworkBrowser::IP);
+        map.insert(configGroup.readEntry("ColumnPositionComment", (int)Smb4KNetworkBrowser::Comment), Smb4KNetworkBrowser::Comment);
 
-    QMap<int, int>::const_iterator it = map.constBegin();
+        QMap<int, int>::const_iterator it = map.constBegin();
 
-    while (it != map.constEnd()) {
-        if (it.key() != m_networkBrowser->header()->visualIndex(it.value())) {
-            m_networkBrowser->header()->moveSection(m_networkBrowser->header()->visualIndex(it.value()), it.key());
+        while (it != map.constEnd()) {
+            if (it.key() != m_networkBrowser->header()->visualIndex(it.value())) {
+                m_networkBrowser->header()->moveSection(m_networkBrowser->header()->visualIndex(it.value()), it.key());
+            }
+
+            ++it;
         }
-
-        ++it;
     }
 
-    //
-    // Apply the completion strings to the search toolbar
-    //
-    m_searchToolBar->setCompletionStrings(configGroup.readEntry("SearchItemCompletion", QStringList()));
+    KConfigGroup completionGroup(Smb4KSettings::self()->config(), QStringLiteral("CompletionItems"));
+
+    if (completionGroup.exists()) {
+        m_searchToolBar->setCompletionItems(completionGroup.readEntry("SearchItemCompletion", QStringList()));
+    }
 
     //
     // Does anything has to be changed with the marked shares?
@@ -306,21 +290,16 @@ void Smb4KNetworkBrowserDockWidget::loadSettings()
 
 void Smb4KNetworkBrowserDockWidget::saveSettings()
 {
-    //
-    // Save the position of the columns
-    //
-    KConfigGroup configGroup(Smb4KSettings::self()->config(), "NetworkBrowserPart");
+    KConfigGroup configGroup(Smb4KSettings::self()->config(), QStringLiteral("NetworkBrowserPart"));
     configGroup.writeEntry("ColumnPositionNetwork", m_networkBrowser->header()->visualIndex(Smb4KNetworkBrowser::Network));
     configGroup.writeEntry("ColumnPositionType", m_networkBrowser->header()->visualIndex(Smb4KNetworkBrowser::Type));
     configGroup.writeEntry("ColumnPositionIP", m_networkBrowser->header()->visualIndex(Smb4KNetworkBrowser::IP));
     configGroup.writeEntry("ColumnPositionComment", m_networkBrowser->header()->visualIndex(Smb4KNetworkBrowser::Comment));
-
-    //
-    // Save the completion strings
-    //
-    configGroup.writeEntry("SearchItemCompletion", m_searchToolBar->completionStrings());
-
     configGroup.sync();
+
+    KConfigGroup completionGroup(Smb4KSettings::self()->config(), QStringLiteral("CompletionItems"));
+    completionGroup.writeEntry("SearchItemCompletion", m_searchToolBar->completionItems());
+    completionGroup.sync();
 }
 
 KActionCollection *Smb4KNetworkBrowserDockWidget::actionCollection()
@@ -333,11 +312,10 @@ void Smb4KNetworkBrowserDockWidget::slotContextMenuRequested(const QPoint &pos)
     m_contextMenu->menu()->popup(m_networkBrowser->viewport()->mapToGlobal(pos));
 }
 
-void Smb4KNetworkBrowserDockWidget::slotItemActivated(QTreeWidgetItem *item, int /*column*/)
+void Smb4KNetworkBrowserDockWidget::slotItemActivated(QTreeWidgetItem *item, int column)
 {
-    //
-    // Process the activated item
-    //
+    Q_UNUSED(column);
+
     if (QApplication::keyboardModifiers() == Qt::NoModifier && m_networkBrowser->selectedItems().size() == 1) {
         Smb4KNetworkBrowserItem *browserItem = static_cast<Smb4KNetworkBrowserItem *>(item);
 
@@ -477,47 +455,33 @@ void Smb4KNetworkBrowserDockWidget::slotItemSelectionChanged()
     }
 }
 
-void Smb4KNetworkBrowserDockWidget::slotClientAboutToStart(const NetworkItemPtr & /*item*/, int process)
+void Smb4KNetworkBrowserDockWidget::slotClientAboutToStart(const NetworkItemPtr &item, int process)
 {
-    //
-    // Get the rescan/abort action
-    //
+    Q_UNUSED(item);
+
     KDualAction *rescanAbortAction = static_cast<KDualAction *>(m_actionCollection->action(QStringLiteral("rescan_abort_action")));
 
-    //
-    // Make adjustments
-    //
     if (rescanAbortAction) {
         rescanAbortAction->setActive(true);
         m_actionCollection->setDefaultShortcut(rescanAbortAction, QKeySequence::Cancel);
     }
 
-    //
-    // Set the active status of the search tool bar
-    //
     if (process == NetworkSearch) {
         m_searchToolBar->setActiveState(true);
     }
 }
 
-void Smb4KNetworkBrowserDockWidget::slotClientFinished(const NetworkItemPtr & /*item*/, int process)
+void Smb4KNetworkBrowserDockWidget::slotClientFinished(const NetworkItemPtr &item, int process)
 {
-    //
-    // Get the rescan/abort action
-    //
+    Q_UNUSED(item);
+
     KDualAction *rescanAbortAction = static_cast<KDualAction *>(m_actionCollection->action(QStringLiteral("rescan_abort_action")));
 
-    //
-    // Make adjustments
-    //
     if (rescanAbortAction) {
         rescanAbortAction->setActive(false);
         m_actionCollection->setDefaultShortcut(rescanAbortAction, QKeySequence::Refresh);
     }
 
-    //
-    // Set the active status of the search tool bar
-    //
     if (process == NetworkSearch) {
         m_searchToolBar->setActiveState(false);
     }
@@ -568,11 +532,6 @@ void Smb4KNetworkBrowserDockWidget::slotWorkgroups()
         // Sort the items
         //
         m_networkBrowser->sortItems(Smb4KNetworkBrowser::Network, Qt::AscendingOrder);
-
-        //
-        // Update the tooltip
-        //
-        m_networkBrowser->toolTip()->update();
     } else {
         //
         // Clear the tree widget
@@ -666,11 +625,6 @@ void Smb4KNetworkBrowserDockWidget::slotWorkgroupMembers(const WorkgroupPtr &wor
             // Sort the items
             //
             m_networkBrowser->sortItems(Smb4KNetworkBrowser::Network, Qt::AscendingOrder);
-
-            //
-            // Update the tooltip
-            //
-            m_networkBrowser->toolTip()->update();
         }
     }
 }
@@ -756,11 +710,6 @@ void Smb4KNetworkBrowserDockWidget::slotShares(const HostPtr &host)
         // Sort the items
         //
         m_networkBrowser->sortItems(Smb4KNetworkBrowser::Network, Qt::AscendingOrder);
-
-        //
-        // Update the tooltip
-        //
-        m_networkBrowser->toolTip()->update();
     }
 }
 
@@ -843,7 +792,13 @@ void Smb4KNetworkBrowserDockWidget::slotAddBookmark(bool checked)
     }
 
     if (!shares.isEmpty()) {
-        Smb4KBookmarkHandler::self()->addBookmarks(shares);
+        QPointer<Smb4KBookmarkDialog> bookmarkDialog = new Smb4KBookmarkDialog(this);
+
+        if (bookmarkDialog->setShares(shares)) {
+            bookmarkDialog->open();
+        } else {
+            delete bookmarkDialog;
+        }
     }
 }
 
@@ -851,7 +806,8 @@ void Smb4KNetworkBrowserDockWidget::slotMountManually(bool checked)
 {
     Q_UNUSED(checked);
 
-    Smb4KMounter::self()->openMountDialog();
+    QPointer<Smb4KMountDialog> mountDialog = new Smb4KMountDialog(this);
+    mountDialog->show();
 }
 
 void Smb4KNetworkBrowserDockWidget::slotAuthentication(bool checked)
@@ -864,18 +820,12 @@ void Smb4KNetworkBrowserDockWidget::slotAuthentication(bool checked)
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         if (item) {
-            switch (item->type()) {
-            case Host: {
-                Smb4KWalletManager::self()->showPasswordDialog(item->hostItem());
-                break;
-            }
-            case Share: {
-                Smb4KWalletManager::self()->showPasswordDialog(item->shareItem());
-                break;
-            }
-            default: {
-                break;
-            }
+            QPointer<Smb4KPasswordDialog> passwordDialog = new Smb4KPasswordDialog(this);
+
+            if (passwordDialog->setNetworkItem(item->networkItem())) {
+                passwordDialog->show();
+            } else {
+                delete passwordDialog;
             }
         }
     }
@@ -890,20 +840,11 @@ void Smb4KNetworkBrowserDockWidget::slotAddCustomSettings(bool checked)
     for (QTreeWidgetItem *selectedItem : qAsConst(selectedItems)) {
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
-        if (item) {
-            switch (item->type()) {
-            case Host: {
-                Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(item->hostItem());
-                break;
-            }
-            case Share: {
-                Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(item->shareItem());
-                break;
-            }
-            default: {
-                break;
-            }
-            }
+        QPointer<Smb4KCustomSettingsEditor> customSettingsEditor = new Smb4KCustomSettingsEditor(this);
+        if (customSettingsEditor->setNetworkItem(item->networkItem())) {
+            customSettingsEditor->show();
+        } else {
+            delete customSettingsEditor;
         }
     }
 }
@@ -918,7 +859,13 @@ void Smb4KNetworkBrowserDockWidget::slotPreview(bool checked)
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         if (item && item->type() == Share && !item->shareItem()->isPrinter()) {
-            Smb4KClient::self()->openPreviewDialog(item->shareItem());
+            QPointer<Smb4KPreviewDialog> previewDialog = new Smb4KPreviewDialog(this);
+
+            if (previewDialog->setShare(item->shareItem())) {
+                previewDialog->show();
+            } else {
+                delete previewDialog;
+            }
         }
     }
 }
@@ -933,7 +880,13 @@ void Smb4KNetworkBrowserDockWidget::slotPrint(bool checked)
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         if (item && item->shareItem()->isPrinter()) {
-            Smb4KClient::self()->openPrintDialog(item->shareItem());
+            QPointer<Smb4KPrintDialog> printDialog = new Smb4KPrintDialog(this);
+
+            if (printDialog->setPrinterShare(item->shareItem())) {
+                printDialog->show();
+            } else {
+                delete printDialog;
+            }
         }
     }
 }
@@ -952,6 +905,24 @@ void Smb4KNetworkBrowserDockWidget::slotMountActionTriggered(bool checked)
             if (item->shareItem()->isMounted()) {
                 mountedShares << item->shareItem();
             } else {
+                if (item->shareItem()->isHomesShare()) {
+                    QPointer<Smb4KHomesUserDialog> homesUserDialog = new Smb4KHomesUserDialog(this);
+                    bool proceed = false;
+
+                    if (homesUserDialog->setShare(item->shareItem())) {
+                        // We want to get a return value here, so we use exec()
+                        if (homesUserDialog->exec() == QDialog::Accepted) {
+                            proceed = true;
+                        }
+                    }
+
+                    delete homesUserDialog;
+
+                    if (!proceed) {
+                        continue;
+                    }
+                }
+
                 unmountedShares << item->shareItem();
             }
         }
@@ -976,9 +947,9 @@ void Smb4KNetworkBrowserDockWidget::slotMountActionChanged(bool active)
     //
     if (mountAction) {
         if (active) {
-            m_actionCollection->setDefaultShortcut(mountAction, QKeySequence(Qt::CTRL + Qt::Key_M));
+            m_actionCollection->setDefaultShortcut(mountAction, QKeySequence(i18n("Ctrl+M")));
         } else {
-            m_actionCollection->setDefaultShortcut(mountAction, QKeySequence(Qt::CTRL + Qt::Key_U));
+            m_actionCollection->setDefaultShortcut(mountAction, QKeySequence(i18n("Ctrl+U")));
         }
     }
 }
@@ -1025,11 +996,9 @@ void Smb4KNetworkBrowserDockWidget::slotShareUnmounted(const SharePtr &share)
     }
 }
 
-void Smb4KNetworkBrowserDockWidget::slotMounterAboutToStart(int /*process*/)
+void Smb4KNetworkBrowserDockWidget::slotMounterAboutToStart(int process)
 {
-    //
-    // Unused at the moment
-    //
+    Q_UNUSED(process);
 }
 
 void Smb4KNetworkBrowserDockWidget::slotMounterFinished(int process)
@@ -1112,14 +1081,7 @@ void Smb4KNetworkBrowserDockWidget::slotPerformSearch(const QString &item)
 
 void Smb4KNetworkBrowserDockWidget::slotStopSearch()
 {
-    //
-    // Stop the network search
-    //
     Smb4KClient::self()->abort();
-
-    //
-    // A global search finished
-    //
     m_searchRunning = false;
 }
 
@@ -1172,9 +1134,6 @@ void Smb4KNetworkBrowserDockWidget::slotSearchResults(const QList<SharePtr> &sha
 
 void Smb4KNetworkBrowserDockWidget::slotJumpToResult(const QString &url)
 {
-    //
-    // Find the share item with URL url
-    //
     QTreeWidgetItemIterator it(m_networkBrowser);
 
     while (*it) {
