@@ -15,8 +15,8 @@
 #include <QStringList>
 
 // KDE includes
-#include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
+#include <KIconLoader>
+#include <KLocalizedString>
 
 Smb4KProfilesMenu::Smb4KProfilesMenu(QObject *parent)
     : KSelectAction(KDE::icon(QStringLiteral("system-users")), i18n("Profiles"), parent)
@@ -32,7 +32,7 @@ Smb4KProfilesMenu::Smb4KProfilesMenu(QObject *parent)
     connect(Smb4KProfileManager::self(), SIGNAL(activeProfileChanged(QString)), this, SLOT(slotActiveProfileChanged(QString)));
     connect(Smb4KProfileManager::self(), SIGNAL(profilesListChanged(QStringList)), this, SLOT(slotProfilesListChanged(QStringList)));
     connect(Smb4KProfileManager::self(), SIGNAL(profileUsageChanged(bool)), this, SLOT(slotProfileUsageChanged(bool)));
-    connect(this, SIGNAL(triggered(QString)), this, SLOT(slotActionTriggered(QString)));
+    connect(this, SIGNAL(textTriggered(QString)), this, SLOT(slotActionTriggered(QString)));
 }
 
 Smb4KProfilesMenu::~Smb4KProfilesMenu()
