@@ -1,18 +1,18 @@
 /*
     smb4ksharesmenu  -  Shares menu
 
-    SPDX-FileCopyrightText: 2011-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2011-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // application specific includes
 #include "smb4ksharesmenu.h"
-#include "core/smb4kbookmarkhandler.h"
-#include "core/smb4kcustomoptionsmanager.h"
 #include "core/smb4kglobal.h"
 #include "core/smb4kmounter.h"
-#include "core/smb4kshare.h"
-#include "core/smb4ksynchronizer.h"
+#include "smb4kbookmarkdialog.h"
+#include "smb4kcustomsettingseditor.h"
+#include "smb4kpreviewdialog.h"
+#include "smb4ksynchronizationdialog.h"
 
 #if defined(Q_OS_LINUX)
 #include "smb4kmountsettings_linux.h"
@@ -23,14 +23,15 @@
 // Qt includes
 #include <QMap>
 #include <QMenu>
+#include <QPointer>
 #include <QStandardPaths>
 #include <QString>
 #include <QStringList>
 #include <QVariant>
 
 // KDE includes
-#include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
+#include <KIconLoader>
+#include <KLocalizedString>
 
 using namespace Smb4KGlobal;
 
@@ -355,11 +356,26 @@ void Smb4KSharesMenu::slotShareAction(QAction *action)
         if (type == QStringLiteral("unmount")) {
             Smb4KMounter::self()->unmountShare(share, false);
         } else if (type == QStringLiteral("bookmark")) {
-            Smb4KBookmarkHandler::self()->addBookmark(share);
+            QPointer<Smb4KBookmarkDialog> bookmarkDialog = new Smb4KBookmarkDialog(menu());
+            if (bookmarkDialog->setShares(QList<SharePtr>({share}))) {
+                bookmarkDialog->open();
+            } else {
+                delete bookmarkDialog;
+            }
         } else if (type == QStringLiteral("options")) {
-            Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(share);
+            QPointer<Smb4KCustomSettingsEditor> customSettingsEditor = new Smb4KCustomSettingsEditor(menu());
+            if (customSettingsEditor->setNetworkItem(share)) {
+                customSettingsEditor->show();
+            } else {
+                delete customSettingsEditor;
+            }
         } else if (type == QStringLiteral("sync")) {
-            Smb4KSynchronizer::self()->synchronize(share);
+            QPointer<Smb4KSynchronizationDialog> synchronizationDialog = new Smb4KSynchronizationDialog(menu());
+            if (synchronizationDialog->setShare(share)) {
+                synchronizationDialog->show();
+            } else {
+                delete synchronizationDialog;
+            }
         } else if (type == QStringLiteral("konsole")) {
             openShare(share, Smb4KGlobal::Konsole);
         } else if (type == QStringLiteral("filemanager")) {
