@@ -112,10 +112,17 @@ protected:
      */
     Qt::DropActions supportedDropActions() const override;
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    /**
+     * Reimplemented to allow dragging.
+     */
+    QMimeData *mimeData(const QList<QListWidgetItem *> &list) const override;
+#else
     /**
      * Reimplemented to allow dragging.
      */
     QMimeData *mimeData(const QList<QListWidgetItem *> list) const override;
+#endif
 
     /**
      * Reimplemented to allow dragging.
