@@ -1,20 +1,23 @@
 /*
     The network search widget dock widget
 
-    SPDX-FileCopyrightText: 2018-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2018-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // application specific includes
 #include "smb4ksharesviewdockwidget.h"
-#include "core/smb4kbookmarkhandler.h"
-#include "core/smb4kcustomoptionsmanager.h"
 #include "core/smb4khardwareinterface.h"
 #include "core/smb4kmounter.h"
 #include "core/smb4ksettings.h"
 #include "core/smb4kshare.h"
 #include "core/smb4ksynchronizer.h"
+#include "smb4kbookmarkdialog.h"
+#include "smb4kcustomsettingseditor.h"
+#include "smb4kpassworddialog.h"
+#include "smb4ksharesview.h"
 #include "smb4ksharesviewitem.h"
+#include "smb4ksynchronizationdialog.h"
 #include "smb4ktooltip.h"
 
 #if defined(Q_OS_LINUX)
@@ -28,55 +31,36 @@
 #include <QApplication>
 #include <QDropEvent>
 #include <QMenu>
+#include <QPointer>
 
 // KDE includes
-#include <KCoreAddons/KJobUiDelegate>
-#include <KI18n/KLocalizedString>
-#include <KIOWidgets/KIO/DropJob>
-#include <KIconThemes/KIconLoader>
-#include <KJobWidgets/KJobWidgets>
-#include <KWidgetsAddons/KMessageBox>
+#include <KIO/DropJob>
+#include <KIconLoader>
+#include <KJobUiDelegate>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 Smb4KSharesViewDockWidget::Smb4KSharesViewDockWidget(const QString &title, QWidget *parent)
     : QDockWidget(title, parent)
 {
-    //
-    // Set the shares view
-    //
     m_sharesView = new Smb4KSharesView(this);
     setWidget(m_sharesView);
 
-    //
-    // The action collection
-    //
     m_actionCollection = new KActionCollection(this);
-
-    //
-    // The context menu
-    //
     m_contextMenu = new KActionMenu(this);
 
-    //
-    // Set up the actions
-    //
     setupActions();
-
-    //
-    // Load the settings
-    //
     loadSettings();
 
-    //
-    // Connections
-    //
-    connect(m_sharesView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenuRequested(QPoint)));
-    connect(m_sharesView, SIGNAL(itemActivated(QListWidgetItem *)), this, SLOT(slotItemActivated(QListWidgetItem *)));
-    connect(m_sharesView, SIGNAL(itemSelectionChanged()), this, SLOT(slotItemSelectionChanged()));
-    connect(m_sharesView, SIGNAL(acceptedDropEvent(Smb4KSharesViewItem *, QDropEvent *)), this, SLOT(slotDropEvent(Smb4KSharesViewItem *, QDropEvent *)));
+    connect(m_sharesView, &Smb4KSharesView::customContextMenuRequested, this, &Smb4KSharesViewDockWidget::slotContextMenuRequested);
+    connect(m_sharesView, &Smb4KSharesView::itemActivated, this, &Smb4KSharesViewDockWidget::slotItemActivated);
+    connect(m_sharesView, &Smb4KSharesView::itemSelectionChanged, this, &Smb4KSharesViewDockWidget::slotItemSelectionChanged);
+    connect(m_sharesView, &Smb4KSharesView::acceptedDropEvent, this, &Smb4KSharesViewDockWidget::slotDropEvent);
 
-    connect(Smb4KMounter::self(), SIGNAL(mounted(SharePtr)), this, SLOT(slotShareMounted(SharePtr)));
-    connect(Smb4KMounter::self(), SIGNAL(unmounted(SharePtr)), this, SLOT(slotShareUnmounted(SharePtr)));
-    connect(Smb4KMounter::self(), SIGNAL(updated(SharePtr)), this, SLOT(slotShareUpdated(SharePtr)));
+    connect(Smb4KMounter::self(), &Smb4KMounter::mounted, this, &Smb4KSharesViewDockWidget::slotShareMounted);
+    connect(Smb4KMounter::self(), &Smb4KMounter::unmounted, this, &Smb4KSharesViewDockWidget::slotShareUnmounted);
+    connect(Smb4KMounter::self(), &Smb4KMounter::updated, this, &Smb4KSharesViewDockWidget::slotShareUpdated);
 }
 
 Smb4KSharesViewDockWidget::~Smb4KSharesViewDockWidget()
@@ -154,7 +138,7 @@ void Smb4KSharesViewDockWidget::setupActions()
 
     QActionGroup *viewModesGroup = new QActionGroup(this);
     viewModesGroup->setExclusive(true);
-    connect(viewModesGroup, SIGNAL(triggered(QAction *)), this, SLOT(slotViewModeChanged(QAction *)));
+    connect(viewModesGroup, &QActionGroup::triggered, this, &Smb4KSharesViewDockWidget::slotViewModeChanged);
 
     QAction *iconViewAction = new QAction(KDE::icon(QStringLiteral("view-list-icons")), i18n("Icon View"), this);
     iconViewAction->setObjectName(QStringLiteral("icon_view_action"));
@@ -197,20 +181,20 @@ void Smb4KSharesViewDockWidget::setupActions()
     //
     QAction *unmountAction = new QAction(KDE::icon(QStringLiteral("media-eject")), i18n("&Unmount"), this);
     unmountAction->setEnabled(false);
-    connect(unmountAction, SIGNAL(triggered(bool)), this, SLOT(slotUnmountActionTriggered(bool)));
+    connect(unmountAction, &QAction::triggered, this, &Smb4KSharesViewDockWidget::slotUnmountActionTriggered);
 
     m_actionCollection->addAction(QStringLiteral("unmount_action"), unmountAction);
-    m_actionCollection->setDefaultShortcut(unmountAction, QKeySequence(Qt::CTRL + Qt::Key_U));
+    m_actionCollection->setDefaultShortcut(unmountAction, QKeySequence(i18n("Ctrl+U")));
 
     //
     // The Unmount All action
     //
     QAction *unmountAllAction = new QAction(KDE::icon(QStringLiteral("system-run")), i18n("U&nmount All"), this);
     unmountAllAction->setEnabled(false);
-    connect(unmountAllAction, SIGNAL(triggered(bool)), this, SLOT(slotUnmountAllActionTriggered(bool)));
+    connect(unmountAllAction, &QAction::triggered, this, &Smb4KSharesViewDockWidget::slotUnmountAllActionTriggered);
 
     m_actionCollection->addAction(QStringLiteral("unmount_all_action"), unmountAllAction);
-    m_actionCollection->setDefaultShortcut(unmountAllAction, QKeySequence(Qt::CTRL + Qt::Key_N));
+    m_actionCollection->setDefaultShortcut(unmountAllAction, QKeySequence(i18n("Ctrl+N")));
 
     //
     // Second separator
@@ -225,30 +209,30 @@ void Smb4KSharesViewDockWidget::setupActions()
     //
     QAction *bookmarkAction = new QAction(KDE::icon(QStringLiteral("bookmark-new")), i18n("Add &Bookmark"), this);
     bookmarkAction->setEnabled(false);
-    connect(bookmarkAction, SIGNAL(triggered(bool)), this, SLOT(slotBookmarkActionTriggered(bool)));
+    connect(bookmarkAction, &QAction::triggered, this, &Smb4KSharesViewDockWidget::slotBookmarkActionTriggered);
 
     m_actionCollection->addAction(QStringLiteral("bookmark_action"), bookmarkAction);
-    m_actionCollection->setDefaultShortcut(bookmarkAction, QKeySequence(Qt::CTRL + Qt::Key_B));
+    m_actionCollection->setDefaultShortcut(bookmarkAction, QKeySequence(i18n("Ctrl+B")));
 
     //
     // Add custom options action
     //
     QAction *customAction = new QAction(KDE::icon(QStringLiteral("settings-configure")), i18n("Add &Custom Settings"), this);
     customAction->setEnabled(false);
-    connect(customAction, SIGNAL(triggered(bool)), this, SLOT(slotAddCustomSettingsTriggered(bool)));
+    connect(customAction, &QAction::triggered, this, &Smb4KSharesViewDockWidget::slotAddCustomSettingsTriggered);
 
     m_actionCollection->addAction(QStringLiteral("custom_action"), customAction);
-    m_actionCollection->setDefaultShortcut(customAction, QKeySequence(Qt::CTRL + Qt::Key_C));
+    m_actionCollection->setDefaultShortcut(customAction, QKeySequence(i18n("Ctrl+C")));
 
     //
     // The Synchronize action
     //
     QAction *synchronizeAction = new QAction(KDE::icon(QStringLiteral("folder-sync")), i18n("S&ynchronize"), this);
     synchronizeAction->setEnabled(false);
-    connect(synchronizeAction, SIGNAL(triggered(bool)), this, SLOT(slotSynchronizeActionTriggered(bool)));
+    connect(synchronizeAction, &QAction::triggered, this, &Smb4KSharesViewDockWidget::slotSynchronizeActionTriggered);
 
     m_actionCollection->addAction(QStringLiteral("synchronize_action"), synchronizeAction);
-    m_actionCollection->setDefaultShortcut(synchronizeAction, QKeySequence(Qt::CTRL + Qt::Key_Y));
+    m_actionCollection->setDefaultShortcut(synchronizeAction, QKeySequence(i18n("Ctrl+Y")));
 
     //
     // Third separator
@@ -263,17 +247,17 @@ void Smb4KSharesViewDockWidget::setupActions()
     //
     QAction *konsoleAction = new QAction(KDE::icon(QStringLiteral("utilities-terminal")), i18n("Open with Konso&le"), this);
     konsoleAction->setEnabled(false);
-    connect(konsoleAction, SIGNAL(triggered(bool)), this, SLOT(slotKonsoleActionTriggered(bool)));
+    connect(konsoleAction, &QAction::triggered, this, &Smb4KSharesViewDockWidget::slotKonsoleActionTriggered);
 
     m_actionCollection->addAction(QStringLiteral("konsole_action"), konsoleAction);
-    m_actionCollection->setDefaultShortcut(konsoleAction, QKeySequence(Qt::CTRL + Qt::Key_L));
+    m_actionCollection->setDefaultShortcut(konsoleAction, QKeySequence(i18n("Ctrl+L")));
 
     QAction *filemanagerAction = new QAction(KDE::icon(QStringLiteral("system-file-manager")), i18n("Open with F&ile Manager"), this);
     filemanagerAction->setEnabled(false);
-    connect(filemanagerAction, SIGNAL(triggered(bool)), this, SLOT(slotFileManagerActionTriggered(bool)));
+    connect(filemanagerAction, &QAction::triggered, this, &Smb4KSharesViewDockWidget::slotFileManagerActionTriggered);
 
     m_actionCollection->addAction(QStringLiteral("filemanager_action"), filemanagerAction);
-    m_actionCollection->setDefaultShortcut(filemanagerAction, QKeySequence(Qt::CTRL + Qt::Key_I));
+    m_actionCollection->setDefaultShortcut(filemanagerAction, QKeySequence(i18n("Ctrl+I")));
 
     //
     // Plug the actions into the context menu
@@ -307,7 +291,7 @@ void Smb4KSharesViewDockWidget::slotItemSelectionChanged()
 
     if (selectedItems.size() == 1) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItems.first());
-        bool syncRunning = Smb4KSynchronizer::self()->isRunning(item->shareItem());
+        bool syncRunning = Smb4KSynchronizer::self()->isRunning(QUrl::fromLocalFile(item->shareItem()->path()));
 
         m_actionCollection->action(QStringLiteral("unmount_action"))
             ->setEnabled((!item->shareItem()->isForeign() || Smb4KMountSettings::unmountForeignShares()));
@@ -334,7 +318,7 @@ void Smb4KSharesViewDockWidget::slotItemSelectionChanged()
 
             if (item) {
                 // Is the share synchronized at the moment?
-                if (Smb4KSynchronizer::self()->isRunning(item->shareItem())) {
+                if (Smb4KSynchronizer::self()->isRunning(QUrl::fromLocalFile(item->shareItem()->path()))) {
                     syncsRunning += 1;
                 }
 
@@ -428,11 +412,6 @@ void Smb4KSharesViewDockWidget::slotShareMounted(const SharePtr &share)
         // Sort the view
         m_sharesView->sortItems(Qt::AscendingOrder);
 
-        //
-        // Update the tooltip
-        //
-        m_sharesView->toolTip()->update();
-
         // Enable/disable the 'Unmount All' action
         actionCollection()
             ->action(QStringLiteral("unmount_all_action"))
@@ -471,10 +450,9 @@ void Smb4KSharesViewDockWidget::slotShareUnmounted(const SharePtr &share)
 
 void Smb4KSharesViewDockWidget::slotShareUpdated(const SharePtr &share)
 {
-    //
-    // Get the share item and updated it
-    //
     if (share) {
+        m_sharesView->toolTip()->update();
+
         for (int i = 0; i < m_sharesView->count(); ++i) {
             Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(m_sharesView->item(i));
 
@@ -525,7 +503,13 @@ void Smb4KSharesViewDockWidget::slotBookmarkActionTriggered(bool checked)
         shares << item->shareItem();
     }
 
-    Smb4KBookmarkHandler::self()->addBookmarks(shares);
+    QPointer<Smb4KBookmarkDialog> bookmarkDialog = new Smb4KBookmarkDialog(this);
+
+    if (bookmarkDialog->setShares(shares)) {
+        bookmarkDialog->open();
+    } else {
+        delete bookmarkDialog;
+    }
 }
 
 void Smb4KSharesViewDockWidget::slotAddCustomSettingsTriggered(bool checked)
@@ -537,8 +521,11 @@ void Smb4KSharesViewDockWidget::slotAddCustomSettingsTriggered(bool checked)
     for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
-        if (item) {
-            Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(item->shareItem());
+        QPointer<Smb4KCustomSettingsEditor> customSettingsEditor = new Smb4KCustomSettingsEditor(this);
+        if (customSettingsEditor->setNetworkItem(item->shareItem())) {
+            customSettingsEditor->show();
+        } else {
+            delete customSettingsEditor;
         }
     }
 }
@@ -552,8 +539,13 @@ void Smb4KSharesViewDockWidget::slotSynchronizeActionTriggered(bool checked)
     for (QListWidgetItem *selectedItem : qAsConst(selectedItems)) {
         Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(selectedItem);
 
-        if (item && !item->shareItem()->isInaccessible() && !Smb4KSynchronizer::self()->isRunning(item->shareItem())) {
-            Smb4KSynchronizer::self()->synchronize(item->shareItem());
+        if (item && !item->shareItem()->isInaccessible() && !Smb4KSynchronizer::self()->isRunning(QUrl::fromLocalFile(item->shareItem()->path()))) {
+            QPointer<Smb4KSynchronizationDialog> synchronizationDialog = new Smb4KSynchronizationDialog(this);
+            if (synchronizationDialog->setShare(item->shareItem())) {
+                synchronizationDialog->show();
+            } else {
+                delete synchronizationDialog;
+            }
         }
     }
 }
